@@ -62,11 +62,17 @@ def create_server(conn):
     keypair = create_keypair(conn)
 
     server = conn.compute.create_server(
-        name=SERVER_NAME, image_id=image.id, flavor_id=flavor.id,
-        networks=[{"uuid": network.id}], key_name=keypair.name)
+        name=SERVER_NAME,
+        image_id=image.id,
+        flavor_id=flavor.id,
+        networks=[{"uuid": network.id}],
+        key_name=keypair.name,
+    )
 
     server = conn.compute.wait_for_server(server)
 
-    print("ssh -i {key} root@{ip}".format(
-        key=PRIVATE_KEYPAIR_FILE,
-        ip=server.access_ipv4))
+    print(
+        "ssh -i {key} root@{ip}".format(
+            key=PRIVATE_KEYPAIR_FILE, ip=server.access_ipv4
+        )
+    )
