@@ -15,25 +15,14 @@ import warnings
 from openstack.block_storage.v3._proxy import Proxy
 from openstack.block_storage.v3 import quota_set as _qs
 from openstack.cloud import _utils
-from openstack.cloud import exc
 from openstack import exceptions
-from openstack import proxy
 from openstack import warnings as os_warnings
 
 
-def _no_pending_volumes(volumes):
-    """If there are any volumes not in a steady state, don't cache"""
-    for volume in volumes:
-        if volume['status'] not in ('available', 'error', 'in-use'):
-            return False
-    return True
-
-
 class BlockStorageCloudMixin:
     block_storage: Proxy
 
     # TODO(stephenfin): Remove 'cache' in a future major version
-    @_utils.cache_on_arguments(should_cache_fn=_no_pending_volumes)
     def list_volumes(self, cache=True):
         """List all available volumes.
 
@@ -48,7 +37,6 @@ class BlockStorageCloudMixin:
         return list(self.block_storage.volumes())
 
     # TODO(stephenfin): Remove 'get_extra' in a future major version
-    @_utils.cache_on_arguments()
     def list_volume_types(self, get_extra=None):
         """List all available volume types.
 
@@ -145,9 +133,12 @@ class BlockStorageCloudMixin:
         :param bootable: (optional) Make this volume bootable. If set, wait
             will also be set to true.
         :param kwargs: Keyword arguments as expected for cinder client.
+
         :returns: The created volume ``Volume`` object.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         if bootable is not None:
             wait = True
@@ -155,7 +146,7 @@ class BlockStorageCloudMixin:
         if image:
             image_obj = self.get_image(image)
             if not image_obj:
-                raise exc.OpenStackCloudException(
+                raise exceptions.SDKException(
                     "Image {image} was requested as the basis for a new"
                     " volume, but was not found on the cloud".format(
                         image=image
@@ -167,10 +158,8 @@ class BlockStorageCloudMixin:
 
         volume = self.block_storage.create_volume(**kwargs)
 
-        self.list_volumes.invalidate(self)
-
         if volume['status'] == 'error':
-            raise exc.OpenStackCloudException("Error in creating volume")
+            raise exceptions.SDKException("Error in creating volume")
 
         if wait:
             self.block_storage.wait_for_status(volume, wait=timeout)
@@ -190,14 +179,10 @@ class BlockStorageCloudMixin:
 
         volume = self.get_volume(name_or_id)
         if not volume:
-            raise exc.OpenStackCloudException(
-                "Volume %s not found." % name_or_id
-            )
+            raise exceptions.SDKException("Volume %s not found." % name_or_id)
 
         volume = self.block_storage.update_volume(volume, **kwargs)
 
-        self.list_volumes.invalidate(self)
-
         return volume
 
     def set_volume_bootable(self, name_or_id, bootable=True):
@@ -207,15 +192,17 @@ class BlockStorageCloudMixin:
         :param bool bootable: Whether the volume should be bootable.
             (Defaults to True)
 
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
         :returns: None
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
 
         volume = self.get_volume(name_or_id)
 
         if not volume:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Volume {name_or_id} does not exist".format(
                     name_or_id=name_or_id
                 )
@@ -237,12 +224,13 @@ class BlockStorageCloudMixin:
         :param timeout: Seconds to wait for volume deletion. None is forever.
         :param force: Force delete volume even if the volume is in deleting
             or error_deleting state.
-        :returns: True if deletion was successful, else False.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
-        """
 
-        self.list_volumes.invalidate(self)
+        :returns: True if deletion was successful, else False.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
+        """
         volume = self.block_storage.find_volume(name_or_id)
 
         if not volume:
@@ -258,7 +246,6 @@ class BlockStorageCloudMixin:
             self.log.exception("error in deleting volume")
             raise
 
-        self.list_volumes.invalidate(self)
         if wait:
             self.block_storage.wait_for_delete(volume, wait=timeout)
 
@@ -279,7 +266,6 @@ class BlockStorageCloudMixin:
                     volumes.append(volume)
         return volumes
 
-    # TODO(stephenfin): Convert to use proxy
     def get_volume_limits(self, name_or_id=None):
         """Get volume limits for the current project
 
@@ -288,23 +274,12 @@ class BlockStorageCloudMixin:
         :returns: The volume ``Limit`` object if found, else None.
         """
         params = {}
-        project_id = None
-        error_msg = "Failed to get limits"
         if name_or_id:
-            proj = self.get_project(name_or_id)
-            if not proj:
-                raise exc.OpenStackCloudException("project does not exist")
-            project_id = proj.id
-            params['tenant_id'] = project_id
-            error_msg = "{msg} for the project: {project} ".format(
-                msg=error_msg, project=name_or_id
-            )
-
-        data = proxy._json_response(
-            self.block_storage.get('/limits', params=params)
-        )
-        limits = self._get_and_munchify('limits', data)
-        return limits
+            project = self.get_project(name_or_id)
+            if not project:
+                raise exceptions.SDKException("project does not exist")
+            params['project'] = project
+        return self.block_storage.get_limits(**params)
 
     def get_volume_id(self, name_or_id):
         """Get ID of a volume.
@@ -347,9 +322,12 @@ class BlockStorageCloudMixin:
         :param volume: The volume dict to detach.
         :param wait: If true, waits for volume to be detached.
         :param timeout: Seconds to wait for volume detachment. None is forever.
+
         :returns: None
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         self.compute.delete_volume_attachment(
             server=server['id'],
@@ -384,19 +362,22 @@ class BlockStorageCloudMixin:
         :param device: The device name where the volume will attach.
         :param wait: If true, waits for volume to be attached.
         :param timeout: Seconds to wait for volume attachment. None is forever.
+
         :returns: a volume attachment object.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         dev = self.get_volume_attach_device(volume, server['id'])
         if dev:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Volume %s already attached to server %s on device %s"
                 % (volume['id'], server['id'], dev)
             )
 
         if volume['status'] != 'available':
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Volume %s is not available. Status is '%s'"
                 % (volume['id'], volume['status'])
             )
@@ -452,9 +433,12 @@ class BlockStorageCloudMixin:
         :param wait: If true, waits for volume snapshot to be created.
         :param timeout: Seconds to wait for volume snapshot creation. None is
             forever.
+
         :returns: The created volume ``Snapshot`` object.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         kwargs = self._get_volume_kwargs(kwargs)
         payload = {'volume_id': volume_id, 'force': force}
@@ -530,9 +514,12 @@ class BlockStorageCloudMixin:
             forever.
         :param incremental: If set to true, the backup will be incremental.
         :param snapshot_id: The UUID of the source snapshot to back up.
+
         :returns: The created volume ``Backup`` object.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         payload = {
             'name': name,
@@ -626,12 +613,14 @@ class BlockStorageCloudMixin:
         :param force: Allow delete in state other than error or available.
         :param wait: If true, waits for volume backup to be deleted.
         :param timeout: Seconds to wait for volume backup deletion. None is
-                        forever.
-        :returns: True if deletion was successful, else False.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
-        """
+            forever.
 
+        :returns: True if deletion was successful, else False.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
+        """
         volume_backup = self.get_volume_backup(name_or_id)
 
         if not volume_backup:
@@ -657,9 +646,12 @@ class BlockStorageCloudMixin:
         :param wait: If true, waits for volume snapshot to be deleted.
         :param timeout: Seconds to wait for volume snapshot deletion. None is
             forever.
+
         :returns: True if deletion was successful, else False.
-        :raises: OpenStackCloudTimeout if wait time exceeded.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if wait time
+            exceeded.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         volumesnapshot = self.get_volume_snapshot(name_or_id)
 
@@ -794,11 +786,12 @@ class BlockStorageCloudMixin:
 
         :param name_or_id: Name or unique ID of the volume type.
         :returns: A volume ``Type`` object if found, else None.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         volume_type = self.get_volume_type(name_or_id)
         if not volume_type:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "VolumeType not found: %s" % name_or_id
             )
 
@@ -811,12 +804,14 @@ class BlockStorageCloudMixin:
 
         :param name_or_id: ID or name of a volume_type
         :param project_id: A project id
+
         :returns: None
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         volume_type = self.get_volume_type(name_or_id)
         if not volume_type:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "VolumeType not found: %s" % name_or_id
             )
 
@@ -827,12 +822,14 @@ class BlockStorageCloudMixin:
 
         :param name_or_id: ID or name of a volume_type
         :param project_id: A project id
+
         :returns: None
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         volume_type = self.get_volume_type(name_or_id)
         if not volume_type:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "VolumeType not found: %s" % name_or_id
             )
         self.block_storage.remove_type_access(volume_type, project_id)
@@ -842,9 +839,10 @@ class BlockStorageCloudMixin:
 
         :param name_or_id: project name or id
         :param kwargs: key/value pairs of quota name and quota value
+
         :returns: None
-        :raises: OpenStackCloudException if the resource to set the
-            quota does not exist.
+        :raises: :class:`~openstack.exceptions.SDKException` if the resource to
+            set the quota does not exist.
         """
 
         proj = self.identity.find_project(name_or_id, ignore_missing=False)
@@ -857,8 +855,10 @@ class BlockStorageCloudMixin:
         """Get volume quotas for a project
 
         :param name_or_id: project name or id
+
         :returns: A volume ``QuotaSet`` object with the quotas
-        :raises: OpenStackCloudException if it's not a valid project
+        :raises: :class:`~openstack.exceptions.SDKException` if it's not a
+            valid project
         """
         proj = self.identity.find_project(name_or_id, ignore_missing=False)
 
@@ -868,9 +868,10 @@ class BlockStorageCloudMixin:
         """Delete volume quotas for a project
 
         :param name_or_id: project name or id
+
         :returns: The deleted volume ``QuotaSet`` object.
-        :raises: OpenStackCloudException if it's not a valid project or the
-            call failed
+        :raises: :class:`~openstack.exceptions.SDKException` if it's not a
+            valid project or the call failed
         """
         proj = self.identity.find_project(name_or_id, ignore_missing=False)
 
