@@ -11,7 +11,6 @@
 # limitations under the License.
 
 import ipaddress
-import threading
 import time
 import warnings
 
@@ -24,11 +23,6 @@ from openstack import proxy
 from openstack import utils
 from openstack import warnings as os_warnings
 
-_CONFIG_DOC_URL = (
-    "https://docs.openstack.org/openstacksdk/latest/"
-    "user/config/configuration.html"
-)
-
 
 class FloatingIPCloudMixin:
     network: Proxy
@@ -43,14 +37,6 @@ class FloatingIPCloudMixin:
             else:
                 self._floating_ip_source = self._floating_ip_source.lower()
 
-        self._floating_ips = None
-        self._floating_ips_time = 0
-        self._floating_ips_lock = threading.Lock()
-
-        self._floating_network_by_router = None
-        self._floating_network_by_router_run = False
-        self._floating_network_by_router_lock = threading.Lock()
-
     def search_floating_ip_pools(self, name=None, filters=None):
         pools = self.list_floating_ip_pools()
         return _utils._filter_list(pools, name, filters)
@@ -81,7 +67,7 @@ class FloatingIPCloudMixin:
     def _nova_list_floating_ips(self):
         try:
             data = proxy._json_response(self.compute.get('/os-floating-ips'))
-        except exc.OpenStackCloudURINotFound:
+        except exceptions.NotFoundException:
             return []
         return self._get_and_munchify('floating_ips', data)
 
@@ -110,39 +96,45 @@ class FloatingIPCloudMixin:
         """
         return _utils._get_entity(self, 'floating_ip', id, filters)
 
-    def _list_floating_ips(self, filters=None):
+    def list_floating_ips(self, filters=None):
+        """List all available floating IPs.
+
+        :param filters: (optional) dict of filter conditions to push down
+        :returns: A list of floating IP
+            ``openstack.network.v2.floating_ip.FloatingIP``.
+        """
+        if not filters:
+            filters = {}
+
         if self._use_neutron_floating():
             try:
                 return self._neutron_list_floating_ips(filters)
-            except exc.OpenStackCloudURINotFound as e:
+            except exceptions.NotFoundException as e:
                 # Nova-network don't support server-side floating ips
-                # filtering, so it's safer to return and empty list than
+                # filtering, so it's safer to return an empty list than
                 # to fallback to Nova which may return more results that
                 # expected.
                 if filters:
                     self.log.error(
-                        "Neutron returned NotFound for floating IPs, which"
-                        " means this cloud doesn't have neutron floating ips."
-                        " shade can't fallback to trying Nova since nova"
-                        " doesn't support server-side filtering when listing"
-                        " floating ips and filters were given. If you do not"
-                        " think shade should be attempting to list floating"
-                        " ips on neutron, it is possible to control the"
-                        " behavior by setting floating_ip_source to 'nova' or"
-                        " None for cloud: %(cloud)s. If you are not already"
-                        " using clouds.yaml to configure settings for your"
-                        " cloud(s), and you want to configure this setting,"
-                        " you will need a clouds.yaml file. For more"
-                        " information, please see %(doc_url)s",
+                        "Neutron returned NotFound for floating IPs, which "
+                        "means this cloud doesn't have neutron floating ips. "
+                        "openstacksdk can't fallback to trying Nova since "
+                        "nova doesn't support server-side filtering when "
+                        "listing floating ips and filters were given. "
+                        "If you do not think openstacksdk should be "
+                        "attempting to list floating IPs on neutron, it is "
+                        "possible to control the behavior by setting "
+                        "floating_ip_source to 'nova' or None for cloud "
+                        "%(cloud)r in 'clouds.yaml'.",
                         {
                             'cloud': self.name,
-                            'doc_url': _CONFIG_DOC_URL,
                         },
                     )
                     # We can't fallback to nova because we push-down filters.
                     # We got a 404 which means neutron doesn't exist. If the
                     # user
                     return []
+
                 self.log.debug(
                     "Something went wrong talking to neutron API: "
                     "'%(msg)s'. Trying with Nova.",
@@ -153,7 +145,7 @@ class FloatingIPCloudMixin:
             if filters:
                 raise ValueError(
                     "Nova-network don't support server-side floating ips "
-                    "filtering. Use the search_floatting_ips method instead"
+                    "filtering. Use the search_floating_ips method instead"
                 )
 
         floating_ips = self._nova_list_floating_ips()
@@ -167,9 +159,7 @@ class FloatingIPCloudMixin:
         neutron. `get_external_ipv4_floating_networks` is what you should
         almost certainly be using.
 
-        :returns: A list of floating IP pool
-            ``openstack.network.v2.floating_ip.FloatingIP``.
-
+        :returns: A list of floating IP pools
         """
         if not self._has_nova_extension('os-floating-ip-pools'):
             raise exc.OpenStackCloudUnavailableExtension(
@@ -183,40 +173,6 @@ class FloatingIPCloudMixin:
         pools = self._get_and_munchify('floating_ip_pools', data)
         return [{'name': p['name']} for p in pools]
 
-    def list_floating_ips(self, filters=None):
-        """List all available floating IPs.
-
-        :param filters: (optional) dict of filter conditions to push down
-        :returns: A list of floating IP
-            ``openstack.network.v2.floating_ip.FloatingIP``.
-
-        """
-        # If pushdown filters are specified and we do not have batched caching
-        # enabled, bypass local caching and push down the filters.
-        if filters and self._FLOAT_AGE == 0:
-            return self._list_floating_ips(filters)
-
-        if (time.time() - self._floating_ips_time) >= self._FLOAT_AGE:
-            # Since we're using cached data anyway, we don't need to
-            # have more than one thread actually submit the list
-            # floating ips task.  Let the first one submit it while holding
-            # a lock, and the non-blocking acquire method will cause
-            # subsequent threads to just skip this and use the old
-            # data until it succeeds.
-            # Initially when we never got data, block to retrieve some data.
-            first_run = self._floating_ips is None
-            if self._floating_ips_lock.acquire(first_run):
-                try:
-                    if not (first_run and self._floating_ips is not None):
-                        self._floating_ips = self._list_floating_ips()
-                        self._floating_ips_time = time.time()
-                finally:
-                    self._floating_ips_lock.release()
-        # Wrap the return with filter_list so that if filters were passed
-        # but we were batching/caching and thus always fetching the whole
-        # list from the cloud, we still return a filtered list.
-        return _utils._filter_list(self._floating_ips, None, filters)
-
     def get_floating_ip_by_id(self, id):
         """Get a floating ip by ID
 
@@ -250,9 +206,8 @@ class FloatingIPCloudMixin:
         :param server: (server) Server the Floating IP is for
 
         :returns: a list of floating IP addresses.
-
-        :raises: ``OpenStackCloudResourceNotFound``, if an external network
-            that meets the specified criteria cannot be found.
+        :raises: :class:`~openstack.exceptions.BadRequestException` if an
+            external network that meets the specified criteria cannot be found.
         """
         if project_id is None:
             # Make sure we are only listing floatingIPs allocated the current
@@ -274,7 +229,7 @@ class FloatingIPCloudMixin:
                     break
 
             if floating_network_id is None:
-                raise exc.OpenStackCloudResourceNotFound(
+                raise exceptions.NotFoundException(
                     "unable to find external network {net}".format(net=network)
                 )
         else:
@@ -286,7 +241,7 @@ class FloatingIPCloudMixin:
             'project_id': project_id,
         }
 
-        floating_ips = self._list_floating_ips()
+        floating_ips = self.list_floating_ips()
         available_ips = _utils._filter_list(
             floating_ips, name_or_id=None, filters=filters
         )
@@ -310,9 +265,8 @@ class FloatingIPCloudMixin:
         :param pool: Nova floating IP pool name.
 
         :returns: a list of floating IP addresses.
-
-        :raises: ``OpenStackCloudResourceNotFound``, if a floating IP pool
-            is not specified and cannot be found.
+        :raises: :class:`~openstack.exceptions.BadRequestException` if a
+            floating IP pool is not specified and cannot be found.
         """
 
         with _utils.openstacksdk_exceptions(
@@ -321,7 +275,7 @@ class FloatingIPCloudMixin:
             if pool is None:
                 pools = self.list_floating_ip_pools()
                 if not pools:
-                    raise exc.OpenStackCloudResourceNotFound(
+                    raise exceptions.NotFoundException(
                         "unable to find a floating ip pool"
                     )
                 pool = pools[0]['name']
@@ -343,25 +297,13 @@ class FloatingIPCloudMixin:
 
     def _find_floating_network_by_router(self):
         """Find the network providing floating ips by looking at routers."""
-
-        if self._floating_network_by_router_lock.acquire(
-            not self._floating_network_by_router_run
-        ):
-            if self._floating_network_by_router_run:
-                self._floating_network_by_router_lock.release()
-                return self._floating_network_by_router
-            try:
-                for router in self.list_routers():
-                    if router['admin_state_up']:
-                        network_id = router.get(
-                            'external_gateway_info', {}
-                        ).get('network_id')
-                        if network_id:
-                            self._floating_network_by_router = network_id
-            finally:
-                self._floating_network_by_router_run = True
-                self._floating_network_by_router_lock.release()
-        return self._floating_network_by_router
+        for router in self.list_routers():
+            if router['admin_state_up']:
+                network_id = router.get('external_gateway_info', {}).get(
+                    'network_id'
+                )
+                if network_id:
+                    return network_id
 
     def available_floating_ip(self, network=None, server=None):
         """Get a floating IP from a network or a pool.
@@ -380,7 +322,7 @@ class FloatingIPCloudMixin:
                     network=network, server=server
                 )
                 return f_ips[0]
-            except exc.OpenStackCloudURINotFound as e:
+            except exceptions.NotFoundException as e:
                 self.log.debug(
                     "Something went wrong talking to neutron API: "
                     "'%(msg)s'. Trying with Nova.",
@@ -403,7 +345,7 @@ class FloatingIPCloudMixin:
             if floating_network:
                 floating_network_id = floating_network
             else:
-                raise exc.OpenStackCloudResourceNotFound(
+                raise exceptions.NotFoundException(
                     "unable to find an external network"
                 )
         return floating_network_id
@@ -441,8 +383,8 @@ class FloatingIPCloudMixin:
                         provided.
 
         :returns: a floating IP address
-
-        :raises: ``OpenStackCloudException``, on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         if self._use_neutron_floating():
             try:
@@ -455,7 +397,7 @@ class FloatingIPCloudMixin:
                     wait=wait,
                     timeout=timeout,
                 )
-            except exc.OpenStackCloudURINotFound as e:
+            except exceptions.NotFoundException as e:
                 self.log.debug(
                     "Something went wrong talking to neutron API: "
                     "'%(msg)s'. Trying with Nova.",
@@ -464,7 +406,7 @@ class FloatingIPCloudMixin:
                 # Fall-through, trying with Nova
 
         if port:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "This cloud uses nova-network which does not support"
                 " arbitrary floating-ip/port mappings. Please nudge"
                 " your cloud provider to upgrade the networking stack"
@@ -497,7 +439,7 @@ class FloatingIPCloudMixin:
                 try:
                     network = self.network.find_network(network_name_or_id)
                 except exceptions.ResourceNotFound:
-                    raise exc.OpenStackCloudResourceNotFound(
+                    raise exceptions.NotFoundException(
                         "unable to find network for floating ips with ID "
                         "{0}".format(network_name_or_id)
                     )
@@ -533,12 +475,12 @@ class FloatingIPCloudMixin:
                     for count in utils.iterate_timeout(
                         timeout,
                         "Timeout waiting for the floating IP to be ACTIVE",
-                        wait=self._FLOAT_AGE,
+                        wait=min(5, timeout),
                     ):
                         fip = self.get_floating_ip(fip_id)
                         if fip and fip['status'] == 'ACTIVE':
                             break
-                except exc.OpenStackCloudTimeout:
+                except exceptions.ResourceTimeout:
                     self.log.error(
                         "Timed out on floating ip %(fip)s becoming active."
                         " Deleting",
@@ -556,7 +498,7 @@ class FloatingIPCloudMixin:
                     raise
             if fip['port_id'] != port:
                 if server:
-                    raise exc.OpenStackCloudException(
+                    raise exceptions.SDKException(
                         "Attempted to create FIP on port {port} for server"
                         " {server} but FIP has port {port_id}".format(
                             port=port,
@@ -565,7 +507,7 @@ class FloatingIPCloudMixin:
                         )
                     )
                 else:
-                    raise exc.OpenStackCloudException(
+                    raise exceptions.SDKException(
                         "Attempted to create FIP on port {port}"
                         " but something went wrong".format(port=port)
                     )
@@ -578,7 +520,7 @@ class FloatingIPCloudMixin:
             if pool is None:
                 pools = self.list_floating_ip_pools()
                 if not pools:
-                    raise exc.OpenStackCloudResourceNotFound(
+                    raise exceptions.NotFoundException(
                         "unable to find a floating ip pool"
                     )
                 pool = pools[0]['name']
@@ -605,9 +547,9 @@ class FloatingIPCloudMixin:
                       occur.
 
         :returns: True if the IP address has been deleted, False if the IP
-                  address was not found.
-
-        :raises: ``OpenStackCloudException``, on operation error.
+            address was not found.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         for count in range(0, max(0, retry) + 1):
             result = self._delete_floating_ip(floating_ip_id)
@@ -615,10 +557,6 @@ class FloatingIPCloudMixin:
             if (retry == 0) or not result:
                 return result
 
-            # Wait for the cached floating ip list to be regenerated
-            if self._FLOAT_AGE:
-                time.sleep(self._FLOAT_AGE)
-
             # neutron sometimes returns success when deleting a floating
             # ip. That's awesome. SO - verify that the delete actually
             # worked. Some clouds will set the status to DOWN rather than
@@ -627,7 +565,7 @@ class FloatingIPCloudMixin:
             if not f_ip or f_ip['status'] == 'DOWN':
                 return True
 
-        raise exc.OpenStackCloudException(
+        raise exceptions.SDKException(
             "Attempted to delete Floating IP {ip} with ID {id} a total of"
             " {retry} times. Although the cloud did not indicate any errors"
             " the floating ip is still in existence. Aborting further"
@@ -642,7 +580,7 @@ class FloatingIPCloudMixin:
         if self._use_neutron_floating():
             try:
                 return self._neutron_delete_floating_ip(floating_ip_id)
-            except exc.OpenStackCloudURINotFound as e:
+            except exceptions.NotFoundException as e:
                 self.log.debug(
                     "Something went wrong talking to neutron API: "
                     "'%(msg)s'. Trying with Nova.",
@@ -667,7 +605,7 @@ class FloatingIPCloudMixin:
                     fip_id=floating_ip_id
                 ),
             )
-        except exc.OpenStackCloudURINotFound:
+        except exceptions.NotFoundException:
             return False
         return True
 
@@ -690,8 +628,8 @@ class FloatingIPCloudMixin:
                       occur.
 
         :returns: Number of Floating IPs deleted, False if none
-
-        :raises: ``OpenStackCloudException``, on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         processed = []
         if self._use_neutron_floating():
@@ -730,8 +668,8 @@ class FloatingIPCloudMixin:
                                 FIP to attach to will come from.
 
         :returns: The server ``openstack.compute.v2.server.Server``
-
-        :raises: OpenStackCloudException, on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         # Short circuit if we're asking to attach an IP that's already
         # attached
@@ -758,7 +696,7 @@ class FloatingIPCloudMixin:
                         fixed_address=fixed_address,
                         nat_destination=nat_destination,
                     )
-                except exc.OpenStackCloudURINotFound as e:
+                except exceptions.NotFoundException as e:
                     self.log.debug(
                         "Something went wrong talking to neutron API: "
                         "'%(msg)s'. Trying with Nova.",
@@ -779,7 +717,7 @@ class FloatingIPCloudMixin:
             for _ in utils.iterate_timeout(
                 timeout,
                 "Timeout waiting for the floating IP to be attached.",
-                wait=self._SERVER_AGE,
+                wait=min(5, timeout),
             ):
                 server = self.get_server_by_id(server_id)
                 ext_ip = meta.get_server_ip(
@@ -799,7 +737,7 @@ class FloatingIPCloudMixin:
             nat_destination=nat_destination,
         )
         if not port:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "unable to find a port for server {0}".format(server['id'])
             )
 
@@ -814,7 +752,7 @@ class FloatingIPCloudMixin:
     ):
         f_ip = self.get_floating_ip(id=floating_ip_id)
         if f_ip is None:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "unable to find floating IP {0}".format(floating_ip_id)
             )
         error_message = "Error attaching IP {ip} to instance {id}".format(
@@ -838,16 +776,16 @@ class FloatingIPCloudMixin:
         :param floating_ip_id: Id of the floating IP to detach.
 
         :returns: True if the IP has been detached, or False if the IP wasn't
-                  attached to any server.
-
-        :raises: ``OpenStackCloudException``, on operation error.
+            attached to any server.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         if self._use_neutron_floating():
             try:
                 return self._neutron_detach_ip_from_server(
                     server_id=server_id, floating_ip_id=floating_ip_id
                 )
-            except exc.OpenStackCloudURINotFound as e:
+            except exceptions.NotFoundException as e:
                 self.log.debug(
                     "Something went wrong talking to neutron API: "
                     "'%(msg)s'. Trying with Nova.",
@@ -881,7 +819,7 @@ class FloatingIPCloudMixin:
     def _nova_detach_ip_from_server(self, server_id, floating_ip_id):
         f_ip = self.get_floating_ip(id=floating_ip_id)
         if f_ip is None:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "unable to find floating IP {0}".format(floating_ip_id)
             )
         error_message = "Error detaching IP {ip} from instance {id}".format(
@@ -942,9 +880,6 @@ class FloatingIPCloudMixin:
                 timeout=timeout,
             )
             timeout = timeout - (time.time() - start_time)
-            # Wait for cache invalidation time so that we don't try
-            # to attach the FIP a second time below
-            time.sleep(self._SERVER_AGE)
             server = self.get_server(server.id)
 
         # We run attach as a second call rather than in the create call
@@ -985,11 +920,11 @@ class FloatingIPCloudMixin:
                                           floating IP should be on
 
         :returns: The updated server ``openstack.compute.v2.server.Server``
-
-        :raises: ``OpenStackCloudException``, on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
 
-        if type(ips) != list:
+        if type(ips) is list:
             ips = [ips]
 
         for ip in ips:
@@ -1063,7 +998,7 @@ class FloatingIPCloudMixin:
                 timeout=timeout,
                 skip_attach=skip_attach,
             )
-        except exc.OpenStackCloudTimeout:
+        except exceptions.ResourceTimeout:
             if self._use_neutron_floating() and created:
                 # We are here because we created an IP on the port
                 # It failed. Delete so as not to leak an unmanaged
@@ -1195,7 +1130,7 @@ class FloatingIPCloudMixin:
         # No floating ip network - no FIPs
         try:
             self._get_floating_network_id()
-        except exc.OpenStackCloudException:
+        except exceptions.SDKException:
             return False
 
         (port_obj, fixed_ip_address) = self._nat_destination_port(
@@ -1222,33 +1157,18 @@ class FloatingIPCloudMixin:
         :param fixed_address: Fixed ip address of the port
         :param nat_destination: Name or ID of the network of the port.
         """
-        # If we are caching port lists, we may not find the port for
-        # our server if the list is old.  Try for at least 2 cache
-        # periods if that is the case.
-        if self._PORT_AGE:
-            timeout = self._PORT_AGE * 2
-        else:
-            timeout = None
-        for count in utils.iterate_timeout(
-            timeout,
-            "Timeout waiting for port to show up in list",
-            wait=self._PORT_AGE,
-        ):
-            try:
-                port_filter = {'device_id': server['id']}
-                ports = self.search_ports(filters=port_filter)
-                break
-            except exc.OpenStackCloudTimeout:
-                ports = None
+        port_filter = {'device_id': server['id']}
+        ports = self.search_ports(filters=port_filter)
         if not ports:
             return (None, None)
+
         port = None
         if not fixed_address:
             if len(ports) > 1:
                 if nat_destination:
                     nat_network = self.get_network(nat_destination)
                     if not nat_network:
-                        raise exc.OpenStackCloudException(
+                        raise exceptions.SDKException(
                             'NAT Destination {nat_destination} was configured'
                             ' but not found on the cloud. Please check your'
                             ' config and your cloud and try again.'.format(
@@ -1259,7 +1179,7 @@ class FloatingIPCloudMixin:
                     nat_network = self.get_nat_destination()
 
                 if not nat_network:
-                    raise exc.OpenStackCloudException(
+                    raise exceptions.SDKException(
                         'Multiple ports were found for server {server}'
                         ' but none of the networks are a valid NAT'
                         ' destination, so it is impossible to add a'
@@ -1277,7 +1197,7 @@ class FloatingIPCloudMixin:
                     if maybe_port['network_id'] == nat_network['id']:
                         maybe_ports.append(maybe_port)
                 if not maybe_ports:
-                    raise exc.OpenStackCloudException(
+                    raise exceptions.SDKException(
                         'No port on server {server} was found matching'
                         ' your NAT destination network {dest}. Please '
                         ' check your config'.format(
@@ -1303,7 +1223,7 @@ class FloatingIPCloudMixin:
                     if ip.version == 4:
                         fixed_address = address['ip_address']
                         return port, fixed_address
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "unable to find a free fixed IPv4 address for server "
                 "{0}".format(server['id'])
             )
