@@ -10,12 +10,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# import types so that we can reference ListType in sphinx param declarations.
-# We can't just use list, because sphinx gets confused by
-# openstack.resource.Resource.list and openstack.resource2.Resource.list
-# import jsonpatch
-import types  # noqa
-
 from openstack.cloud import _utils
 from openstack.cloud import exc
 from openstack import exceptions
@@ -134,7 +128,8 @@ class SecurityGroupCloudMixin:
         :returns: A ``openstack.network.v2.security_group.SecurityGroup``
             representing the new security group.
 
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         :raises: OpenStackCloudUnavailableFeature if security groups are
             not supported on this cloud.
         """
@@ -171,7 +166,8 @@ class SecurityGroupCloudMixin:
 
         :returns: True if delete succeeded, False otherwise.
 
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         :raises: OpenStackCloudUnavailableFeature if security groups are
             not supported on this cloud.
         """
@@ -214,8 +210,8 @@ class SecurityGroupCloudMixin:
 
         :returns: A ``openstack.network.v2.security_group.SecurityGroup``
             describing the updated security group.
-
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         # Security groups not supported
         if not self._has_secgroups():
@@ -226,7 +222,7 @@ class SecurityGroupCloudMixin:
         group = self.get_security_group(name_or_id)
 
         if group is None:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Security group %s not found." % name_or_id
             )
 
@@ -304,10 +300,11 @@ class SecurityGroupCloudMixin:
             on (admin-only).
         :param string description:
             Description of the rule, max 255 characters.
+
         :returns: A ``openstack.network.v2.security_group.SecurityGroup``
             representing the new security group rule.
-
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         # Security groups not supported
         if not self._has_secgroups():
@@ -317,7 +314,7 @@ class SecurityGroupCloudMixin:
 
         secgroup = self.get_security_group(secgroup_name_or_id)
         if not secgroup:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Security group %s not found." % secgroup_name_or_id
             )
 
@@ -347,15 +344,13 @@ class SecurityGroupCloudMixin:
         else:
             # NOTE: Neutron accepts None for protocol. Nova does not.
             if protocol is None:
-                raise exc.OpenStackCloudException('Protocol must be specified')
+                raise exceptions.SDKException('Protocol must be specified')
 
             if direction == 'egress':
                 self.log.debug(
                     'Rule creation failed: Nova does not support egress rules'
                 )
-                raise exc.OpenStackCloudException(
-                    'No support for egress rules'
-                )
+                raise exceptions.SDKException('No support for egress rules')
 
             # NOTE: Neutron accepts None for ports, but Nova requires -1
             # as the equivalent value for ICMP.
@@ -405,7 +400,8 @@ class SecurityGroupCloudMixin:
 
         :returns: True if delete succeeded, False otherwise.
 
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         :raises: OpenStackCloudUnavailableFeature if security groups are
             not supported on this cloud.
         """
@@ -428,7 +424,7 @@ class SecurityGroupCloudMixin:
                         '/os-security-group-rules/{id}'.format(id=rule_id)
                     )
                 )
-            except exc.OpenStackCloudResourceNotFound:
+            except exceptions.NotFoundException:
                 return False
 
             return True
