@@ -14,7 +14,6 @@
 
 import contextlib
 import fnmatch
-import functools
 import inspect
 import re
 import uuid
@@ -24,10 +23,7 @@ import jmespath
 import netifaces
 
 from openstack import _log
-from openstack.cloud import exc
-
-
-_decorated_methods = []
+from openstack import exceptions
 
 
 def _dictify_resource(resource):
@@ -181,7 +177,7 @@ def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
         entities = search(name_or_id, filters, **kwargs)
         if entities:
             if len(entities) > 1:
-                raise exc.OpenStackCloudException(
+                raise exceptions.SDKException(
                     "Multiple matches found for %s" % name_or_id
                 )
             return entities[0]
@@ -230,68 +226,29 @@ def valid_kwargs(*valid_args):
     return func_wrapper
 
 
-def _func_wrap(f):
-    # NOTE(morgan): This extra wrapper is intended to eliminate ever
-    # passing a bound method to dogpile.cache's cache_on_arguments. In
-    # 0.7.0 and later it is impossible to pass bound methods to the
-    # decorator. This was introduced when utilizing the decorate module in
-    # lieu of a direct wrap implementation.
-    @functools.wraps(f)
-    def inner(*args, **kwargs):
-        return f(*args, **kwargs)
-
-    return inner
-
-
-def cache_on_arguments(*cache_on_args, **cache_on_kwargs):
-    _cache_name = cache_on_kwargs.pop('resource', None)
-
-    def _inner_cache_on_arguments(func):
-        def _cache_decorator(obj, *args, **kwargs):
-            the_method = obj._get_cache(_cache_name).cache_on_arguments(
-                *cache_on_args, **cache_on_kwargs
-            )(_func_wrap(func.__get__(obj, type(obj))))
-            return the_method(*args, **kwargs)
-
-        def invalidate(obj, *args, **kwargs):
-            return (
-                obj._get_cache(_cache_name)
-                .cache_on_arguments()(func)
-                .invalidate(*args, **kwargs)
-            )
-
-        _cache_decorator.invalidate = invalidate
-        _cache_decorator.func = func
-        _decorated_methods.append(func.__name__)
-
-        return _cache_decorator
-
-    return _inner_cache_on_arguments
-
-
 @contextlib.contextmanager
 def openstacksdk_exceptions(error_message=None):
     """Context manager for dealing with openstack exceptions.
 
     :param string error_message: String to use for the exception message
-        content on non-OpenStackCloudExceptions.
+        content on non-SDKException exception.
 
-        Useful for avoiding wrapping OpenStackCloudException exceptions
+        Useful for avoiding wrapping SDKException exceptions
         within themselves. Code called from within the context may throw such
         exceptions without having to catch and reraise them.
 
-        Non-OpenStackCloudException exceptions thrown within the context will
+        Non-SDKException exceptions thrown within the context will
         be wrapped and the exception message will be appended to the given
         error message.
     """
     try:
         yield
-    except exc.OpenStackCloudException:
+    except exceptions.SDKException:
         raise
     except Exception as e:
         if error_message is None:
             error_message = str(e)
-        raise exc.OpenStackCloudException(error_message)
+        raise exceptions.SDKException(error_message)
 
 
 def safe_dict_min(key, data):
@@ -316,7 +273,7 @@ def safe_dict_min(key, data):
             try:
                 val = int(d[key])
             except ValueError:
-                raise exc.OpenStackCloudException(
+                raise exceptions.SDKException(
                     "Search for minimum value failed. "
                     "Value for {key} is not an integer: {value}".format(
                         key=key, value=d[key]
@@ -349,7 +306,7 @@ def safe_dict_max(key, data):
             try:
                 val = int(d[key])
             except ValueError:
-                raise exc.OpenStackCloudException(
+                raise exceptions.SDKException(
                     "Search for maximum value failed. "
                     "Value for {key} is not an integer: {value}".format(
                         key=key, value=d[key]
@@ -403,7 +360,8 @@ def range_filter(data, key, range_exp):
     :param string range_exp: The expression describing the range of values.
 
     :returns: A list subset of the original data set.
-    :raises: OpenStackCloudException on invalid range expressions.
+    :raises: :class:`~openstack.exceptions.SDKException` on invalid range
+        expressions.
     """
     filtered = []
     range_exp = str(range_exp).upper()
@@ -431,7 +389,7 @@ def range_filter(data, key, range_exp):
 
     # If parsing the range fails, it must be a bad value.
     if val_range is None:
-        raise exc.OpenStackCloudException(
+        raise exceptions.SDKException(
             "Invalid range value: {value}".format(value=range_exp)
         )
 
