@@ -9,47 +9,35 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import copy
 import functools
 import queue
-import six
-# import types so that we can reference ListType in sphinx param declarations.
-# We can't just use list, because sphinx gets confused by
-# openstack.resource.Resource.list and openstack.resource2.Resource.list
-import types  # noqa
 import warnings
 
 import dogpile.cache
-import munch
+import keystoneauth1.exceptions
+import keystoneauth1.session
 import requests.models
 import requestsexceptions
 
-import keystoneauth1.exceptions
-import keystoneauth1.session
-
 from openstack import _log
-from openstack.cloud import exc
-from openstack.cloud import _floating_ip
 from openstack.cloud import _object_store
-from openstack.cloud import meta
 from openstack.cloud import _utils
+from openstack.cloud import meta
 import openstack.config
 from openstack.config import cloud_region as cloud_region_mod
+from openstack import exceptions
 from openstack import proxy
 from openstack import utils
 
-DEFAULT_SERVER_AGE = 5
-DEFAULT_PORT_AGE = 5
-DEFAULT_FLOAT_AGE = 5
-_CONFIG_DOC_URL = _floating_ip._CONFIG_DOC_URL
-
 DEFAULT_OBJECT_SEGMENT_SIZE = _object_store.DEFAULT_OBJECT_SEGMENT_SIZE
 # This halves the current default for Swift
 DEFAULT_MAX_FILE_SIZE = _object_store.DEFAULT_MAX_FILE_SIZE
 OBJECT_CONTAINER_ACLS = _object_store.OBJECT_CONTAINER_ACLS
 
 
-class _OpenStackCloudMixin(object):
+class _OpenStackCloudMixin:
     """Represent a connection to an OpenStack Cloud.
 
     OpenStackCloud is the entry point for all cloud operations, regardless
@@ -62,9 +50,10 @@ class _OpenStackCloudMixin(object):
     :param bool strict: Only return documented attributes for each resource
                         as per the Data Model contract. (Default False)
     """
-    _OBJECT_MD5_KEY = 'x-object-meta-x-sdk-md5'
-    _OBJECT_SHA256_KEY = 'x-object-meta-x-sdk-sha256'
-    _OBJECT_AUTOCREATE_KEY = 'x-object-meta-x-sdk-autocreated'
+
+    _OBJECT_MD5_KEY = 'x-sdk-md5'
+    _OBJECT_SHA256_KEY = 'x-sdk-sha256'
+    _OBJECT_AUTOCREATE_KEY = 'x-sdk-autocreated'
     _OBJECT_AUTOCREATE_CONTAINER = 'images'
 
     # NOTE(shade) shade keys were x-object-meta-x-shade-md5 - we need to check
@@ -75,7 +64,6 @@ class _OpenStackCloudMixin(object):
     _SHADE_OBJECT_AUTOCREATE_KEY = 'x-object-meta-x-shade-autocreated'
 
     def __init__(self):
-
         super(_OpenStackCloudMixin, self).__init__()
 
         self.log = _log.setup_logging('openstack')
@@ -92,7 +80,8 @@ class _OpenStackCloudMixin(object):
         # cert verification
         if not self.verify:
             self.log.debug(
-                "Turning off Insecure SSL warnings since verify=False")
+                "Turning off Insecure SSL warnings since verify=False"
+            )
             category = requestsexceptions.InsecureRequestWarning
             if category:
                 # InsecureRequestWarning references a Warning class or is None
@@ -104,61 +93,22 @@ class _OpenStackCloudMixin(object):
         cache_class = self.config.get_cache_class()
         cache_arguments = self.config.get_cache_arguments()
 
-        self._resource_caches = {}
+        self._cache_expirations = dict()
 
         if cache_class != 'dogpile.cache.null':
             self.cache_enabled = True
-            self._cache = self._make_cache(
-                cache_class, cache_expiration_time, cache_arguments)
-            expirations = self.config.get_cache_expirations()
-            for expire_key in expirations.keys():
-                # Only build caches for things we have list operations for
-                if getattr(
-                        self, 'list_{0}'.format(expire_key), None):
-                    self._resource_caches[expire_key] = self._make_cache(
-                        cache_class, expirations[expire_key], cache_arguments)
-
-            self._SERVER_AGE = DEFAULT_SERVER_AGE
-            self._PORT_AGE = DEFAULT_PORT_AGE
-            self._FLOAT_AGE = DEFAULT_FLOAT_AGE
         else:
             self.cache_enabled = False
 
-            def _fake_invalidate(unused):
-                pass
-
-            class _FakeCache(object):
-                def invalidate(self):
-                    pass
-
-            # Don't cache list_servers if we're not caching things.
-            # Replace this with a more specific cache configuration
-            # soon.
-            self._SERVER_AGE = 0
-            self._PORT_AGE = 0
-            self._FLOAT_AGE = 0
-            self._cache = _FakeCache()
-            # Undecorate cache decorated methods. Otherwise the call stacks
-            # wind up being stupidly long and hard to debug
-            for method in _utils._decorated_methods:
-                meth_obj = getattr(self, method, None)
-                if not meth_obj:
-                    continue
-                if (hasattr(meth_obj, 'invalidate')
-                        and hasattr(meth_obj, 'func')):
-                    new_func = functools.partial(meth_obj.func, self)
-                    new_func.invalidate = _fake_invalidate
-                    setattr(self, method, new_func)
-
-        # If server expiration time is set explicitly, use that. Otherwise
-        # fall back to whatever it was before
-        self._SERVER_AGE = self.config.get_cache_resource_expiration(
-            'server', self._SERVER_AGE)
-        self._PORT_AGE = self.config.get_cache_resource_expiration(
-            'port', self._PORT_AGE)
-        self._FLOAT_AGE = self.config.get_cache_resource_expiration(
-            'floating_ip', self._FLOAT_AGE)
+        # Uncoditionally create cache even with a "null" backend
+        self._cache = self._make_cache(
+            cache_class, cache_expiration_time, cache_arguments
+        )
+        expirations = self.config.get_cache_expirations()
+        for expire_key in expirations.keys():
+            self._cache_expirations[expire_key] = expirations[expire_key]
 
+        self._api_cache_keys = set()
         self._container_cache = dict()
         self._file_hash_cache = dict()
 
@@ -167,7 +117,8 @@ class _OpenStackCloudMixin(object):
         self._raw_clients = {}
 
         self._local_ipv6 = (
-            _utils.localhost_supports_ipv6() if not self.force_ipv4 else False)
+            _utils.localhost_supports_ipv6() if not self.force_ipv4 else False
+        )
 
     def connect_as(self, **kwargs):
         """Make a new OpenStackCloud object with new auth context.
@@ -199,7 +150,8 @@ class _OpenStackCloudMixin(object):
             config = openstack.config.OpenStackConfig(
                 app_name=self.config._app_name,
                 app_version=self.config._app_version,
-                load_yaml_config=False)
+                load_yaml_config=False,
+            )
         params = copy.deepcopy(self.config.config)
         # Remove profile from current cloud so that overridding works
         params.pop('profile', None)
@@ -306,7 +258,8 @@ class _OpenStackCloudMixin(object):
             app_name=self.config._app_name,
             app_version=self.config._app_version,
             discovery_cache=self.session._discovery_cache,
-            **params)
+            **params,
+        )
 
         # Override the cloud name so that logging/location work right
         cloud_region._name = self.name
@@ -321,9 +274,8 @@ class _OpenStackCloudMixin(object):
         return dogpile.cache.make_region(
             function_key_generator=self._make_cache_key
         ).configure(
-            cache_class,
-            expiration_time=expiration_time,
-            arguments=arguments)
+            cache_class, expiration_time=expiration_time, arguments=arguments
+        )
 
     def _make_cache_key(self, namespace, fn):
         fname = fn.__name__
@@ -333,158 +285,22 @@ class _OpenStackCloudMixin(object):
             name_key = '%s:%s' % (self.name, namespace)
 
         def generate_key(*args, **kwargs):
-            arg_key = ','.join(args)
+            # TODO(frickler): make handling arg keys actually work
+            arg_key = ''
             kw_keys = sorted(kwargs.keys())
             kwargs_key = ','.join(
-                ['%s:%s' % (k, kwargs[k]) for k in kw_keys if k != 'cache'])
-            ans = "_".join(
-                [str(name_key), fname, arg_key, kwargs_key])
+                ['%s:%s' % (k, kwargs[k]) for k in kw_keys if k != 'cache']
+            )
+            ans = "_".join([str(name_key), fname, arg_key, kwargs_key])
             return ans
+
         return generate_key
 
-    def _get_cache(self, resource_name):
-        if resource_name and resource_name in self._resource_caches:
-            return self._resource_caches[resource_name]
-        else:
-            return self._cache
-
-    def _get_major_version_id(self, version):
-        if isinstance(version, int):
-            return version
-        elif isinstance(version, six.string_types + (tuple,)):
-            return int(version[0])
-        return version
-
-    def _get_versioned_client(
-            self, service_type, min_version=None, max_version=None):
-        config_version = self.config.get_api_version(service_type)
-        config_major = self._get_major_version_id(config_version)
-        max_major = self._get_major_version_id(max_version)
-        min_major = self._get_major_version_id(min_version)
-        # TODO(shade) This should be replaced with use of Connection. However,
-        #             we need to find a sane way to deal with this additional
-        #             logic - or we need to give up on it. If we give up on it,
-        #             we need to make sure we can still support it in the shade
-        #             compat layer.
-        # NOTE(mordred) This logic for versions is slightly different
-        # than the ksa Adapter constructor logic. openstack.cloud knows the
-        # versions it knows, and uses them when it detects them. However, if
-        # a user requests a version, and it's not found, and a different one
-        # openstack.cloud does know about is found, that's a warning in
-        # openstack.cloud.
-        if config_version:
-            if min_major and config_major < min_major:
-                raise exc.OpenStackCloudException(
-                    "Version {config_version} requested for {service_type}"
-                    " but shade understands a minimum of {min_version}".format(
-                        config_version=config_version,
-                        service_type=service_type,
-                        min_version=min_version))
-            elif max_major and config_major > max_major:
-                raise exc.OpenStackCloudException(
-                    "Version {config_version} requested for {service_type}"
-                    " but openstack.cloud understands a maximum of"
-                    " {max_version}".format(
-                        config_version=config_version,
-                        service_type=service_type,
-                        max_version=max_version))
-            request_min_version = config_version
-            request_max_version = '{version}.latest'.format(
-                version=config_major)
-            adapter = proxy._ShadeAdapter(
-                session=self.session,
-                service_type=self.config.get_service_type(service_type),
-                service_name=self.config.get_service_name(service_type),
-                interface=self.config.get_interface(service_type),
-                endpoint_override=self.config.get_endpoint(service_type),
-                region_name=self.config.get_region_name(service_type),
-                statsd_prefix=self.config.get_statsd_prefix(),
-                statsd_client=self.config.get_statsd_client(),
-                prometheus_counter=self.config.get_prometheus_counter(),
-                prometheus_histogram=self.config.get_prometheus_histogram(),
-                influxdb_client=self.config.get_influxdb_client(),
-                min_version=request_min_version,
-                max_version=request_max_version)
-            if adapter.get_endpoint():
-                return adapter
-
-        adapter = proxy._ShadeAdapter(
-            session=self.session,
-            service_type=self.config.get_service_type(service_type),
-            service_name=self.config.get_service_name(service_type),
-            interface=self.config.get_interface(service_type),
-            endpoint_override=self.config.get_endpoint(service_type),
-            region_name=self.config.get_region_name(service_type),
-            min_version=min_version,
-            max_version=max_version)
-
-        # data.api_version can be None if no version was detected, such
-        # as with neutron
-        api_version = adapter.get_api_major_version(
-            endpoint_override=self.config.get_endpoint(service_type))
-        api_major = self._get_major_version_id(api_version)
-
-        # If we detect a different version that was configured, warn the user.
-        # shade still knows what to do - but if the user gave us an explicit
-        # version and we couldn't find it, they may want to investigate.
-        if api_version and config_version and (api_major != config_major):
-            warning_msg = (
-                '{service_type} is configured for {config_version}'
-                ' but only {api_version} is available. shade is happy'
-                ' with this version, but if you were trying to force an'
-                ' override, that did not happen. You may want to check'
-                ' your cloud, or remove the version specification from'
-                ' your config.'.format(
-                    service_type=service_type,
-                    config_version=config_version,
-                    api_version='.'.join([str(f) for f in api_version])))
-            self.log.debug(warning_msg)
-            warnings.warn(warning_msg)
-        return adapter
-
-    # TODO(shade) This should be replaced with using openstack Connection
-    #             object.
-    def _get_raw_client(
-            self, service_type, api_version=None, endpoint_override=None):
-        return proxy._ShadeAdapter(
-            session=self.session,
-            service_type=self.config.get_service_type(service_type),
-            service_name=self.config.get_service_name(service_type),
-            interface=self.config.get_interface(service_type),
-            endpoint_override=self.config.get_endpoint(
-                service_type) or endpoint_override,
-            region_name=self.config.get_region_name(service_type))
-
-    def _is_client_version(self, client, version):
-        client_name = '_{client}_client'.format(
-            client=client.replace('-', '_'))
-        client = getattr(self, client_name)
-        return client._version_matches(version)
-
-    @property
-    def _application_catalog_client(self):
-        if 'application-catalog' not in self._raw_clients:
-            self._raw_clients['application-catalog'] = self._get_raw_client(
-                'application-catalog')
-        return self._raw_clients['application-catalog']
-
-    @property
-    def _database_client(self):
-        if 'database' not in self._raw_clients:
-            self._raw_clients['database'] = self._get_raw_client('database')
-        return self._raw_clients['database']
-
-    @property
-    def _raw_image_client(self):
-        if 'raw-image' not in self._raw_clients:
-            image_client = self._get_raw_client('image')
-            self._raw_clients['raw-image'] = image_client
-        return self._raw_clients['raw-image']
-
     def pprint(self, resource):
         """Wrapper around pprint that groks munch objects"""
         # import late since this is a utility function
         import pprint
+
         new_resource = _utils._dictify_resource(resource)
         pprint.pprint(new_resource)
 
@@ -492,6 +308,7 @@ class _OpenStackCloudMixin(object):
         """Wrapper around pformat that groks munch objects"""
         # import late since this is a utility function
         import pprint
+
         new_resource = _utils._dictify_resource(resource)
         return pprint.pformat(new_resource)
 
@@ -528,7 +345,8 @@ class _OpenStackCloudMixin(object):
         return self.config.get_endpoint_from_catalog(
             service_type=service_type,
             interface=interface,
-            region_name=region_name)
+            region_name=region_name,
+        )
 
     @property
     def auth_token(self):
@@ -557,11 +375,11 @@ class _OpenStackCloudMixin(object):
 
     @property
     def current_project(self):
-        """Return a ``munch.Munch`` describing the current project"""
+        """Return a ``utils.Munch`` describing the current project"""
         return self._get_project_info()
 
     def _get_project_info(self, project_id=None):
-        project_info = munch.Munch(
+        project_info = utils.Munch(
             id=project_id,
             name=None,
             domain_id=None,
@@ -587,11 +405,11 @@ class _OpenStackCloudMixin(object):
 
     @property
     def current_location(self):
-        """Return a ``munch.Munch`` explaining the current cloud location."""
+        """Return a ``utils.Munch`` explaining the current cloud location."""
         return self._get_current_location()
 
     def _get_current_location(self, project_id=None, zone=None):
-        return munch.Munch(
+        return utils.Munch(
             cloud=self.name,
             # TODO(efried): This is wrong, but it only seems to be used in a
             # repr; can we get rid of it?
@@ -600,58 +418,6 @@ class _OpenStackCloudMixin(object):
             project=self._get_project_info(project_id),
         )
 
-    def _get_identity_location(self):
-        '''Identity resources do not exist inside of projects.'''
-        return munch.Munch(
-            cloud=self.name,
-            region_name=None,
-            zone=None,
-            project=munch.Munch(
-                id=None,
-                name=None,
-                domain_id=None,
-                domain_name=None))
-
-    def _get_project_id_param_dict(self, name_or_id):
-        if name_or_id:
-            project = self.get_project(name_or_id)
-            if not project:
-                return {}
-            if self._is_client_version('identity', 3):
-                return {'default_project_id': project['id']}
-            else:
-                return {'tenant_id': project['id']}
-        else:
-            return {}
-
-    def _get_domain_id_param_dict(self, domain_id):
-        """Get a useable domain."""
-
-        # Keystone v3 requires domains for user and project creation. v2 does
-        # not. However, keystone v2 does not allow user creation by non-admin
-        # users, so we can throw an error to the user that does not need to
-        # mention api versions
-        if self._is_client_version('identity', 3):
-            if not domain_id:
-                raise exc.OpenStackCloudException(
-                    "User or project creation requires an explicit"
-                    " domain_id argument.")
-            else:
-                return {'domain_id': domain_id}
-        else:
-            return {}
-
-    def _get_identity_params(self, domain_id=None, project=None):
-        """Get the domain and project/tenant parameters if needed.
-
-        keystone v2 and v3 are divergent enough that we need to pass or not
-        pass project or tenant_id or domain or nothing in a sane manner.
-        """
-        ret = {}
-        ret.update(self._get_domain_id_param_dict(domain_id))
-        ret.update(self._get_project_id_param_dict(project))
-        return ret
-
     def range_search(self, data, filters):
         """Perform integer range searches across a list of dictionaries.
 
@@ -678,7 +444,8 @@ class _OpenStackCloudMixin(object):
                 {"vcpus": "<=5", "ram": "<=2048", "disk": "1"}
 
         :returns: A list subset of the original data set.
-        :raises: OpenStackCloudException on invalid range expressions.
+        :raises: :class:`~openstack.exceptions.SDKException` on invalid range
+            expressions.
         """
         filtered = []
 
@@ -714,46 +481,132 @@ class _OpenStackCloudMixin(object):
     def get_name(self):
         return self.name
 
-    def get_session_endpoint(self, service_key):
+    def get_session_endpoint(self, service_key, **kwargs):
+        if not kwargs:
+            kwargs = {}
         try:
-            return self.config.get_session_endpoint(service_key)
+            return self.config.get_session_endpoint(service_key, **kwargs)
         except keystoneauth1.exceptions.catalog.EndpointNotFound as e:
             self.log.debug(
-                "Endpoint not found in %s cloud: %s", self.name, str(e))
+                "Endpoint not found in %s cloud: %s", self.name, str(e)
+            )
             endpoint = None
-        except exc.OpenStackCloudException:
+        except exceptions.SDKException:
             raise
         except Exception as e:
-            raise exc.OpenStackCloudException(
+            raise exceptions.SDKException(
                 "Error getting {service} endpoint on {cloud}:{region}:"
                 " {error}".format(
                     service=service_key,
                     cloud=self.name,
                     region=self.config.get_region_name(service_key),
-                    error=str(e)))
+                    error=str(e),
+                )
+            )
         return endpoint
 
-    def has_service(self, service_key):
+    def has_service(self, service_key, version=None):
         if not self.config.has_service(service_key):
             # TODO(mordred) add a stamp here so that we only report this once
-            if not (service_key in self._disable_warnings
-                    and self._disable_warnings[service_key]):
+            if not (
+                service_key in self._disable_warnings
+                and self._disable_warnings[service_key]
+            ):
                 self.log.debug(
-                    "Disabling %(service_key)s entry in catalog"
-                    " per config", {'service_key': service_key})
+                    "Disabling %(service_key)s entry in catalog per config",
+                    {'service_key': service_key},
+                )
                 self._disable_warnings[service_key] = True
             return False
         try:
-            endpoint = self.get_session_endpoint(service_key)
-        except exc.OpenStackCloudException:
+            kwargs = dict()
+            # If a specific version was requested - try it
+            if version is not None:
+                kwargs['min_version'] = version
+                kwargs['max_version'] = version
+            endpoint = self.get_session_endpoint(service_key, **kwargs)
+        except exceptions.SDKException:
             return False
         if endpoint:
             return True
         else:
             return False
 
-    def project_cleanup(self, dry_run=True,
-                        wait_timeout=120, status_queue=None):
+    def search_resources(
+        self,
+        resource_type,
+        name_or_id,
+        get_args=None,
+        get_kwargs=None,
+        list_args=None,
+        list_kwargs=None,
+        **filters,
+    ):
+        """Search resources
+
+        Search resources matching certain conditions
+
+        :param str resource_type: String representation of the expected
+            resource as `service.resource` (i.e. "network.security_group").
+        :param str name_or_id: Name or ID of the resource
+        :param list get_args: Optional args to be passed to the _get call.
+        :param dict get_kwargs: Optional kwargs to be passed to the _get call.
+        :param list list_args: Optional args to be passed to the _list call.
+        :param dict list_kwargs: Optional kwargs to be passed to the _list call
+        :param dict filters: Additional filters to be used for querying
+            resources.
+        """
+        get_args = get_args or ()
+        get_kwargs = get_kwargs or {}
+        list_args = list_args or ()
+        list_kwargs = list_kwargs or {}
+
+        # User used string notation. Try to find proper
+        # resource
+        (service_name, resource_name) = resource_type.split('.')
+        if not hasattr(self, service_name):
+            raise exceptions.SDKException(
+                "service %s is not existing/enabled" % service_name
+            )
+        service_proxy = getattr(self, service_name)
+        try:
+            resource_type = service_proxy._resource_registry[resource_name]
+        except KeyError:
+            raise exceptions.SDKException(
+                "Resource %s is not known in service %s"
+                % (resource_name, service_name)
+            )
+
+        if name_or_id:
+            # name_or_id is definitely not None
+            try:
+                resource_by_id = service_proxy._get(
+                    resource_type, name_or_id, *get_args, **get_kwargs
+                )
+                return [resource_by_id]
+            except exceptions.ResourceNotFound:
+                pass
+
+        if not filters:
+            filters = {}
+
+        if name_or_id:
+            filters["name"] = name_or_id
+        list_kwargs.update(filters)
+
+        return list(
+            service_proxy._list(resource_type, *list_args, **list_kwargs)
+        )
+
+    def project_cleanup(
+        self,
+        dry_run=True,
+        wait_timeout=120,
+        status_queue=None,
+        filters=None,
+        resource_evaluation_fn=None,
+        skip_resources=None,
+    ):
         """Cleanup the project resources.
 
         Cleanup all resources in all services, which provide cleanup methods.
@@ -763,6 +616,14 @@ class _OpenStackCloudMixin(object):
             to comlete the cleanup.
         :param queue status_queue: a threading queue object used to get current
             process status. The queue contain processed resources.
+        :param dict filters: Additional filters for the cleanup (only resources
+            matching all filters will be deleted, if there are no other
+            dependencies).
+        :param resource_evaluation_fn: A callback function, which will be
+            invoked for each resurce and must return True/False depending on
+            whether resource need to be deleted or not.
+        :param skip_resources: List of specific resources whose cleanup should
+            be skipped.
         """
         dependencies = {}
         get_dep_fn_name = '_get_cleanup_dependencies'
@@ -770,36 +631,75 @@ class _OpenStackCloudMixin(object):
         if not status_queue:
             status_queue = queue.Queue()
         for service in self.config.get_enabled_services():
-            if hasattr(self, service):
-                proxy = getattr(self, service)
-                if (proxy
+            try:
+                if hasattr(self, service):
+                    proxy = getattr(self, service)
+                    if (
+                        proxy
                         and hasattr(proxy, get_dep_fn_name)
-                        and hasattr(proxy, cleanup_fn_name)):
-                    deps = getattr(proxy, get_dep_fn_name)()
-                    if deps:
-                        dependencies.update(deps)
+                        and hasattr(proxy, cleanup_fn_name)
+                    ):
+                        deps = getattr(proxy, get_dep_fn_name)()
+                        if deps:
+                            dependencies.update(deps)
+            except (
+                exceptions.NotSupported,
+                exceptions.ServiceDisabledException,
+            ):
+                # Cloud may include endpoint in catalog but not
+                # implement the service or disable it
+                pass
         dep_graph = utils.TinyDAG()
         for k, v in dependencies.items():
             dep_graph.add_node(k)
             for dep in v['before']:
                 dep_graph.add_node(dep)
                 dep_graph.add_edge(k, dep)
+            for dep in v.get('after', []):
+                dep_graph.add_edge(dep, k)
+
+        cleanup_resources = dict()
 
         for service in dep_graph.walk(timeout=wait_timeout):
             fn = None
-            if hasattr(self, service):
-                proxy = getattr(self, service)
-                cleanup_fn = getattr(proxy, cleanup_fn_name, None)
-                if cleanup_fn:
-                    fn = functools.partial(cleanup_fn, dry_run=dry_run,
-                                           status_queue=status_queue)
+            try:
+                if hasattr(self, service):
+                    proxy = getattr(self, service)
+                    cleanup_fn = getattr(proxy, cleanup_fn_name, None)
+                    if cleanup_fn:
+                        fn = functools.partial(
+                            cleanup_fn,
+                            dry_run=dry_run,
+                            client_status_queue=status_queue,
+                            identified_resources=cleanup_resources,
+                            filters=filters,
+                            resource_evaluation_fn=resource_evaluation_fn,
+                            skip_resources=skip_resources,
+                        )
+            except exceptions.ServiceDisabledException:
+                # same reason as above
+                pass
             if fn:
-                self._pool_executor.submit(cleanup_task, dep_graph,
-                                           service, fn)
+                self._pool_executor.submit(
+                    cleanup_task, dep_graph, service, fn
+                )
             else:
                 dep_graph.node_done(service)
 
+        for count in utils.iterate_timeout(
+            timeout=wait_timeout,
+            message="Timeout waiting for cleanup to finish",
+            wait=1,
+        ):
+            if dep_graph.is_complete():
+                return
+
 
 def cleanup_task(graph, service, fn):
-    fn()
-    graph.node_done(service)
+    try:
+        fn()
+    except Exception:
+        log = _log.setup_logging('openstack.project_cleanup')
+        log.exception('Error in the %s cleanup function' % service)
+    finally:
+        graph.node_done(service)
