@@ -9,6 +9,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+import typing as ty
+
 from openstack.common import metadata
 from openstack.common import tag
 from openstack.compute.v2 import flavor
@@ -165,7 +168,6 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     #: routable ipv6 addresses, and to private_ipv4 if the Connection was
     #: created with private=True. Otherwise it will be set to public_ipv4.
     interface_ip = resource.Computed('interface_ip', default='')
-
     # The locked status of the server
     is_locked = resource.Body('locked', type=bool)
     #: The UUID of the kernel image when using an AMI. Will be null if not.
@@ -179,6 +181,8 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     launch_index = resource.Body('OS-EXT-SRV-ATTR:launch_index', type=int)
     #: The timestamp when the server was launched.
     launched_at = resource.Body('OS-SRV-USG:launched_at')
+    #: The reason the server was locked, if any.
+    locked_reason = resource.Body('locked_reason')
     #: The maximum number of servers to create.
     max_count = resource.Body('max_count')
     #: The minimum number of servers to create.
@@ -473,14 +477,13 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
             microversion = '2.45'
         response = self._action(session, body, microversion)
 
-        body = None
         try:
-            # There might be body, might be not
-            body = response.json()
+            # There might be a body, there might not be
+            response_body = response.json()
         except Exception:
-            pass
-        if body and 'image_id' in body:
-            image_id = body['image_id']
+            response_body = None
+        if response_body and 'image_id' in response_body:
+            image_id = response_body['image_id']
         else:
             image_id = response.headers['Location'].rsplit('/', 1)[1]
 
@@ -633,7 +636,7 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         :param locked_reason: The reason for locking the server.
         :returns: None
         """
-        body = {"lock": None}
+        body: ty.Dict[str, ty.Any] = {"lock": None}
         if locked_reason is not None:
             body["lock"] = {
                 "locked_reason": locked_reason,
@@ -661,7 +664,7 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
             provided, the server will use the existing image. (Optional)
         :returns: None
         """
-        body = {"rescue": {}}
+        body: ty.Dict[str, ty.Any] = {"rescue": {}}
         if admin_pass is not None:
             body["rescue"]["adminPass"] = admin_pass
         if image_ref is not None:
@@ -689,7 +692,7 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         :param force: Whether to force evacuation.
         :returns: None
         """
-        body = {"evacuate": {}}
+        body: ty.Dict[str, ty.Any] = {"evacuate": {}}
         if host is not None:
             body["evacuate"]["host"] = host
         if admin_pass is not None:
@@ -794,7 +797,7 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
             (Optional)
         :returns: None
         """
-        body = {"os-getConsoleOutput": {}}
+        body: ty.Dict[str, ty.Any] = {"os-getConsoleOutput": {}}
         if length is not None:
             body["os-getConsoleOutput"]["length"] = length
         resp = self._action(session, body)
@@ -906,7 +909,7 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         disk_over_commit,
     ):
         microversion = None
-        body = {
+        body: ty.Dict[str, ty.Any] = {
             'host': None,
         }
         if block_migration == 'auto':
