@@ -30,8 +30,11 @@ for different ways to create a :class:`~openstack.connection.Connection`.
   might exist inside of an OpenStack service operational context.
 * Using an existing :class:`~openstack.config.cloud_region.CloudRegion`.
 
+Creating the Connection
+-----------------------
+
 Using config settings
----------------------
+~~~~~~~~~~~~~~~~~~~~~
 
 For users who want to create a :class:`~openstack.connection.Connection` making
 use of named clouds in ``clouds.yaml`` files, ``OS_`` environment variables
@@ -57,8 +60,8 @@ then subsequently consumed by the constructor:
     options = argparse.ArgumentParser(description='Awesome OpenStack App')
     conn = openstack.connect(options=options)
 
-Using Only Keyword Arguments
-----------------------------
+Using only keyword arguments
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 If the application wants to avoid loading any settings from ``clouds.yaml`` or
 environment variables, use the :class:`~openstack.connection.Connection`
@@ -79,14 +82,16 @@ settings from files or the environment.
 
     conn = connection.Connection(
         region_name='example-region',
-        auth=dict(
-            auth_url='https://auth.example.com',
-            username='amazing-user',
-            password='super-secret-password',
-            project_id='33aa1afc-03fe-43b8-8201-4e0d3b4b8ab5',
-            user_domain_id='054abd68-9ad9-418b-96d3-3437bb376703'),
+        auth={
+            'auth_url': 'https://auth.example.com',
+            'username': 'amazing-user',
+            'password': 'super-secret-password',
+            'project_id': '33aa1afc-03fe-43b8-8201-4e0d3b4b8ab5',
+            'user_domain_id': '054abd68-9ad9-418b-96d3-3437bb376703'
+        },
         compute_api_version='2',
-        identity_interface='internal')
+        identity_interface='internal',
+    )
 
 Per-service settings as needed by `keystoneauth1.adapter.Adapter` such as
 ``api_version``, ``service_name``, and ``interface`` can be set, as seen
@@ -96,7 +101,7 @@ service. ``region_name`` is a setting for the entire
 service.
 
 From existing authenticated Session
------------------------------------
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 For applications that already have an authenticated Session, simply passing
 it to the :class:`~openstack.connection.Connection` constructor is all that
@@ -110,10 +115,11 @@ is needed:
         session=session,
         region_name='example-region',
         compute_api_version='2',
-        identity_interface='internal')
+        identity_interface='internal',
+    )
 
 From oslo.conf CONF object
---------------------------
+~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 For applications that have an oslo.config ``CONF`` object that has been
 populated with ``keystoneauth1.loading.register_adapter_conf_options`` in
@@ -127,14 +133,100 @@ construct a Connection with the ``CONF`` object and an authenticated Session.
 
 .. code-block:: python
 
+    from keystoneauth1 import loading as ks_loading
+    from oslo_config import cfg
     from openstack import connection
 
+    CONF = cfg.CONF
+
+    group = cfg.OptGroup('neutron')
+    ks_loading.register_session_conf_options(CONF, group)
+    ks_loading.register_auth_conf_options(CONF, group)
+    ks_loading.register_adapter_conf_options(CONF, group)
+
+    CONF()
+
+    auth = ks_loading.load_auth_from_conf_options(CONF, 'neutron')
+    sess = ks_loading.load_session_from_conf_options(CONF, 'neutron', auth=auth)
+
     conn = connection.Connection(
-        session=session,
-        oslo_conf=CONF)
+        session=sess,
+        oslo_conf=CONF,
+    )
+
+This can then be used with an appropriate configuration file.
+
+.. code-block:: ini
+
+    [neutron]
+    region_name = RegionOne
+    auth_strategy = keystone
+    project_domain_name = Default
+    project_name = service
+    user_domain_name = Default
+    password = password
+    username = neutron
+    auth_url = http://10.0.110.85/identity
+    auth_type = password
+    service_metadata_proxy = True
+    default_floating_pool = public
+
+You may also wish to configure a service user. As discussed in the `Keystone
+documentation`__, service users are users with specific roles that identify the
+user as a service. The use of service users can avoid issues caused by the
+expiration of the original user's token during long running operations, as a
+fresh token issued for the service user will always accompany the user's token,
+which may have expired.
+
+.. code-block:: python
+
+    from keystoneauth1 import loading as ks_loading
+    from keystoneauth1 import service_token
+    from oslo_config import cfg
+    import openstack
+    from openstack import connection
+
+    CONF = cfg.CONF
+
+    neutron_group = cfg.OptGroup('neutron')
+    ks_loading.register_session_conf_options(CONF, neutron_group)
+    ks_loading.register_auth_conf_options(CONF, neutron_group)
+    ks_loading.register_adapter_conf_options(CONF, neutron_group)
+
+    service_group = cfg.OptGroup('service_user')
+    ks_loading.register_session_conf_options(CONF, service_group)
+    ks_loading.register_auth_conf_options(CONF, service_group)
+
+    CONF()
+    user_auth = ks_loading.load_auth_from_conf_options(CONF, 'neutron')
+    service_auth = ks_loading.load_auth_from_conf_options(CONF, 'service_user')
+    auth = service_token.ServiceTokenAuthWrapper(user_auth, service_auth)
+
+    sess = ks_loading.load_session_from_conf_options(CONF, 'neutron', auth=auth)
+
+    conn = connection.Connection(
+        session=sess,
+        oslo_conf=CONF,
+    )
+
+This will necessitate an additional section in the configuration file used.
+
+.. code-block:: ini
+
+    [service_user]
+    auth_strategy = keystone
+    project_domain_name = Default
+    project_name = service
+    user_domain_name = Default
+    password = password
+    username = nova
+    auth_url = http://10.0.110.85/identity
+    auth_type = password
+
+.. __: https://docs.openstack.org/keystone/latest/admin/manage-services.html
 
 From existing CloudRegion
--------------------------
+~~~~~~~~~~~~~~~~~~~~~~~~~
 
 If you already have an :class:`~openstack.config.cloud_region.CloudRegion`
 you can pass it in instead:
@@ -145,7 +237,9 @@ you can pass it in instead:
     import openstack.config
 
     config = openstack.config.get_cloud_region(
-        cloud='example', region_name='earth')
+        cloud='example',
+        region_name='earth',
+    )
     conn = connection.Connection(config=config)
 
 Using the Connection
@@ -176,16 +270,12 @@ try to find it and if that fails, you would create it::
 Additional information about the services can be found in the
 :ref:`service-proxies` documentation.
 """
+import atexit
 import concurrent.futures
+import importlib.metadata as importlib_metadata
 import warnings
 import weakref
 
-try:
-    # For python 3.8 and later
-    import importlib.metadata as importlib_metadata
-except ImportError:
-    # For everyone else
-    import importlib_metadata
 import keystoneauth1.exceptions
 import requestsexceptions
 
@@ -194,7 +284,6 @@ from openstack import _services_mixin
 from openstack.cloud import _accelerator
 from openstack.cloud import _baremetal
 from openstack.cloud import _block_storage
-from openstack.cloud import _clustering
 from openstack.cloud import _coe
 from openstack.cloud import _compute
 from openstack.cloud import _dns
@@ -220,7 +309,8 @@ __all__ = [
 
 if requestsexceptions.SubjectAltNameWarning:
     warnings.filterwarnings(
-        'ignore', category=requestsexceptions.SubjectAltNameWarning)
+        'ignore', category=requestsexceptions.SubjectAltNameWarning
+    )
 
 _logger = _log.setup_logging('openstack')
 
@@ -249,7 +339,8 @@ def from_config(cloud=None, config=None, options=None, **kwargs):
     config = kwargs.pop('cloud_config', config)
     if config is None:
         config = _config.OpenStackConfig().get_one(
-            cloud=cloud, argparse=options, **kwargs)
+            cloud=cloud, argparse=options, **kwargs
+        )
 
     return Connection(config=config)
 
@@ -261,7 +352,6 @@ class Connection(
     _baremetal.BaremetalCloudMixin,
     _block_storage.BlockStorageCloudMixin,
     _compute.ComputeCloudMixin,
-    _clustering.ClusteringCloudMixin,
     _coe.CoeCloudMixin,
     _dns.DnsCloudMixin,
     _floating_ip.FloatingIPCloudMixin,
@@ -274,20 +364,25 @@ class Connection(
     _security_group.SecurityGroupCloudMixin,
     _shared_file_system.SharedFileSystemCloudMixin,
 ):
-
-    def __init__(self, cloud=None, config=None, session=None,
-                 app_name=None, app_version=None,
-                 extra_services=None,
-                 strict=False,
-                 use_direct_get=False,
-                 task_manager=None,
-                 rate_limit=None,
-                 oslo_conf=None,
-                 service_types=None,
-                 global_request_id=None,
-                 strict_proxies=False,
-                 pool_executor=None,
-                 **kwargs):
+    def __init__(
+        self,
+        cloud=None,
+        config=None,
+        session=None,
+        app_name=None,
+        app_version=None,
+        extra_services=None,
+        strict=False,
+        use_direct_get=False,
+        task_manager=None,
+        rate_limit=None,
+        oslo_conf=None,
+        service_types=None,
+        global_request_id=None,
+        strict_proxies=False,
+        pool_executor=None,
+        **kwargs
+    ):
         """Create a connection to a cloud.
 
         A connection needs information about how to connect, how to
@@ -373,24 +468,32 @@ class Connection(
         if not self.config:
             if oslo_conf:
                 self.config = cloud_region.from_conf(
-                    oslo_conf, session=session, app_name=app_name,
-                    app_version=app_version, service_types=service_types)
+                    oslo_conf,
+                    session=session,
+                    app_name=app_name,
+                    app_version=app_version,
+                    service_types=service_types,
+                )
             elif session:
                 self.config = cloud_region.from_session(
                     session=session,
-                    app_name=app_name, app_version=app_version,
+                    app_name=app_name,
+                    app_version=app_version,
                     load_yaml_config=False,
                     load_envvars=False,
                     rate_limit=rate_limit,
-                    **kwargs)
+                    **kwargs
+                )
             else:
                 self.config = _config.get_cloud_region(
                     cloud=cloud,
-                    app_name=app_name, app_version=app_version,
+                    app_name=app_name,
+                    app_version=app_version,
                     load_yaml_config=cloud is not None,
                     load_envvars=cloud is not None,
                     rate_limit=rate_limit,
-                    **kwargs)
+                    **kwargs
+                )
 
         self._session = None
         self._proxies = {}
@@ -404,7 +507,6 @@ class Connection(
         _accelerator.AcceleratorCloudMixin.__init__(self)
         _baremetal.BaremetalCloudMixin.__init__(self)
         _block_storage.BlockStorageCloudMixin.__init__(self)
-        _clustering.ClusteringCloudMixin.__init__(self)
         _coe.CoeCloudMixin.__init__(self)
         _compute.ComputeCloudMixin.__init__(self)
         _dns.DnsCloudMixin.__init__(self)
@@ -440,23 +542,28 @@ class Connection(
                         hook = ep.load()
                         hook(self)
                 except ValueError:
-                    self.log.warning('Hook should be in the entrypoint '
-                                     'module:attribute format')
+                    self.log.warning(
+                        'Hook should be in the entrypoint '
+                        'module:attribute format'
+                    )
             except (ImportError, TypeError, AttributeError) as e:
-                self.log.warning('Configured hook %s cannot be executed: %s',
-                                 vendor_hook, e)
+                self.log.warning(
+                    'Configured hook %s cannot be executed: %s', vendor_hook, e
+                )
 
         # Add additional metrics into the configuration according to the
         # selected connection. We don't want to deal with overall config in the
         # proxy, just pass required part.
-        if (self.config._influxdb_config
-                and 'additional_metric_tags' in self.config.config):
-            self.config._influxdb_config['additional_metric_tags'] = \
-                self.config.config['additional_metric_tags']
+        if (
+            self.config._influxdb_config
+            and 'additional_metric_tags' in self.config.config
+        ):
+            self.config._influxdb_config[
+                'additional_metric_tags'
+            ] = self.config.config['additional_metric_tags']
 
-    def __del__(self):
-        # try to force release of resources and save authorization
-        self.close()
+        # Register cleanup steps
+        atexit.register(self.close)
 
     @property
     def session(self):
@@ -500,7 +607,7 @@ class Connection(
             setattr(
                 self.__class__,
                 attr_name.replace('-', '_'),
-                property(fget=getter)
+                property(fget=getter),
             )
         self.config.enable_service(service.service_type)
 
@@ -527,14 +634,16 @@ class Connection(
     def _pool_executor(self):
         if not self.__pool_executor:
             self.__pool_executor = concurrent.futures.ThreadPoolExecutor(
-                max_workers=5)
+                max_workers=5
+            )
         return self.__pool_executor
 
     def close(self):
         """Release any resources held open."""
+        self.config.set_auth_cache()
         if self.__pool_executor:
             self.__pool_executor.shutdown()
-        self.config.set_auth_cache()
+        atexit.unregister(self.close)
 
     def set_global_request_id(self, global_request_id):
         self._global_request_id = global_request_id
