@@ -9,16 +9,27 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from openstack import proxy
+
+from openstack.dns.v2 import floating_ip as _fip
 from openstack.dns.v2 import recordset as _rs
 from openstack.dns.v2 import zone as _zone
-from openstack.dns.v2 import zone_import as _zone_import
 from openstack.dns.v2 import zone_export as _zone_export
+from openstack.dns.v2 import zone_import as _zone_import
+from openstack.dns.v2 import zone_share as _zone_share
 from openstack.dns.v2 import zone_transfer as _zone_transfer
-from openstack.dns.v2 import floating_ip as _fip
+from openstack import proxy
 
 
 class Proxy(proxy.Proxy):
+    _resource_registry = {
+        "floating_ip": _fip.FloatingIP,
+        "recordset": _rs.Recordset,
+        "zone": _zone.Zone,
+        "zone_export": _zone_export.ZoneExport,
+        "zone_import": _zone_import.ZoneImport,
+        "zone_share": _zone_share.ZoneShare,
+        "zone_transfer_request": _zone_transfer.ZoneTransferRequest,
+    }
 
     # ======== Zones ========
     def zones(self, **query):
@@ -54,27 +65,34 @@ class Proxy(proxy.Proxy):
         """Get a zone
 
         :param zone: The value can be the ID of a zone
-             or a :class:`~openstack.dns.v2.zone.Zone` instance.
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
         :returns: Zone instance.
         :rtype: :class:`~openstack.dns.v2.zone.Zone`
         """
         return self._get(_zone.Zone, zone)
 
-    def delete_zone(self, zone, ignore_missing=True):
+    def delete_zone(self, zone, ignore_missing=True, delete_shares=False):
         """Delete a zone
 
         :param zone: The value can be the ID of a zone
-             or a :class:`~openstack.dns.v2.zone.Zone` instance.
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be raised when
             the zone does not exist.
             When set to ``True``, no exception will be set when attempting to
             delete a nonexistent zone.
+        :param bool delete_shares: When True, delete the zone shares along with
+                                   the zone.
 
         :returns: Zone been deleted
         :rtype: :class:`~openstack.dns.v2.zone.Zone`
         """
-        return self._delete(_zone.Zone, zone, ignore_missing=ignore_missing)
+        return self._delete(
+            _zone.Zone,
+            zone,
+            ignore_missing=ignore_missing,
+            delete_shares=delete_shares,
+        )
 
     def update_zone(self, zone, **attrs):
         """Update zone attributes
@@ -88,7 +106,7 @@ class Proxy(proxy.Proxy):
         """
         return self._update(_zone.Zone, zone, **attrs)
 
-    def find_zone(self, name_or_id, ignore_missing=True, **attrs):
+    def find_zone(self, name_or_id, ignore_missing=True):
         """Find a single zone
 
         :param name_or_id: The name or ID of a zone
@@ -100,14 +118,15 @@ class Proxy(proxy.Proxy):
 
         :returns: :class:`~openstack.dns.v2.zone.Zone`
         """
-        return self._find(_zone.Zone, name_or_id,
-                          ignore_missing=ignore_missing)
+        return self._find(
+            _zone.Zone, name_or_id, ignore_missing=ignore_missing
+        )
 
     def abandon_zone(self, zone, **attrs):
         """Abandon Zone
 
         :param zone: The value can be the ID of a zone to be abandoned
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
 
         :returns: None
         """
@@ -119,7 +138,7 @@ class Proxy(proxy.Proxy):
         """Trigger update of secondary Zone
 
         :param zone: The value can be the ID of a zone to be abandoned
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
 
         :returns: None
         """
@@ -131,9 +150,9 @@ class Proxy(proxy.Proxy):
         """Retrieve a generator of recordsets
 
         :param zone: The optional value can be the ID of a zone
-             or a :class:`~openstack.dns.v2.zone.Zone` instance. If it is not
-             given all recordsets for all zones of the tenant would be
-             retrieved
+            or a :class:`~openstack.dns.v2.zone.Zone` instance. If it is not
+            given all recordsets for all zones of the tenant would be
+            retrieved
         :param dict query: Optional query parameters to be sent to limit the
             resources being returned.
 
@@ -184,9 +203,9 @@ class Proxy(proxy.Proxy):
         """Get a recordset
 
         :param zone: The value can be the ID of a zone
-             or a :class:`~openstack.dns.v2.zone.Zone` instance.
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
         :param recordset: The value can be the ID of a recordset
-             or a :class:`~openstack.dns.v2.recordset.Recordset` instance.
+            or a :class:`~openstack.dns.v2.recordset.Recordset` instance.
         :returns: Recordset instance
         :rtype: :class:`~openstack.dns.v2.recordset.Recordset`
         """
@@ -197,10 +216,10 @@ class Proxy(proxy.Proxy):
         """Delete a zone
 
         :param recordset: The value can be the ID of a recordset
-             or a :class:`~openstack.dns.v2.recordset.Recordset`
-             instance.
+            or a :class:`~openstack.dns.v2.recordset.Recordset`
+            instance.
         :param zone: The value can be the ID of a zone
-             or a :class:`~openstack.dns.v2.zone.Zone` instance.
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be raised when
             the zone does not exist. When set to ``True``, no exception will
@@ -211,16 +230,16 @@ class Proxy(proxy.Proxy):
         """
         if zone:
             zone = self._get_resource(_zone.Zone, zone)
-            recordset = self._get(
-                _rs.Recordset, recordset, zone_id=zone.id)
-        return self._delete(_rs.Recordset, recordset,
-                            ignore_missing=ignore_missing)
+            recordset = self._get(_rs.Recordset, recordset, zone_id=zone.id)
+        return self._delete(
+            _rs.Recordset, recordset, ignore_missing=ignore_missing
+        )
 
-    def find_recordset(self, zone, name_or_id, ignore_missing=True, **attrs):
+    def find_recordset(self, zone, name_or_id, ignore_missing=True, **query):
         """Find a single recordset
 
         :param zone: The value can be the ID of a zone
-             or a :class:`~openstack.dns.v2.zone.Zone` instance.
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
         :param name_or_id: The name or ID of a zone
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be raised
@@ -231,9 +250,13 @@ class Proxy(proxy.Proxy):
         :returns: :class:`~openstack.dns.v2.recordset.Recordset`
         """
         zone = self._get_resource(_zone.Zone, zone)
-        return self._find(_rs.Recordset, name_or_id,
-                          ignore_missing=ignore_missing, zone_id=zone.id,
-                          **attrs)
+        return self._find(
+            _rs.Recordset,
+            name_or_id,
+            ignore_missing=ignore_missing,
+            zone_id=zone.id,
+            **query,
+        )
 
     # ======== Zone Imports ========
     def zone_imports(self, **query):
@@ -260,14 +283,15 @@ class Proxy(proxy.Proxy):
         :returns: The results of zone creation.
         :rtype: :class:`~openstack.dns.v2.zone_import.ZoneImport`
         """
-        return self._create(_zone_import.ZoneImport, prepend_key=False,
-                            **attrs)
+        return self._create(
+            _zone_import.ZoneImport, prepend_key=False, **attrs
+        )
 
     def get_zone_import(self, zone_import):
         """Get a zone import record
 
         :param zone: The value can be the ID of a zone import
-             or a :class:`~openstack.dns.v2.zone_import.ZoneImport` instance.
+            or a :class:`~openstack.dns.v2.zone_import.ZoneImport` instance.
         :returns: ZoneImport instance.
         :rtype: :class:`~openstack.dns.v2.zone_import.ZoneImport`
         """
@@ -277,7 +301,7 @@ class Proxy(proxy.Proxy):
         """Delete a zone import
 
         :param zone_import: The value can be the ID of a zone import
-             or a :class:`~openstack.dns.v2.zone_import.ZoneImport` instance.
+            or a :class:`~openstack.dns.v2.zone_import.ZoneImport` instance.
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be raised when
             the zone does not exist.
@@ -286,8 +310,9 @@ class Proxy(proxy.Proxy):
 
         :returns: None
         """
-        return self._delete(_zone_import.ZoneImport, zone_import,
-                            ignore_missing=ignore_missing)
+        return self._delete(
+            _zone_import.ZoneImport, zone_import, ignore_missing=ignore_missing
+        )
 
     # ======== Zone Exports ========
     def zone_exports(self, **query):
@@ -309,7 +334,7 @@ class Proxy(proxy.Proxy):
         """Create a new zone export from attributes
 
         :param zone: The value can be the ID of a zone to be exported
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
         :param dict attrs: Keyword arguments which will be used to create
             a :class:`~openstack.dns.v2.zone_export.ZoneExport`,
             comprised of the properties on the ZoneExport class.
@@ -317,17 +342,19 @@ class Proxy(proxy.Proxy):
         :rtype: :class:`~openstack.dns.v2.zone_export.ZoneExport`
         """
         zone = self._get_resource(_zone.Zone, zone)
-        return self._create(_zone_export.ZoneExport,
-                            base_path='/zones/%(zone_id)s/tasks/export',
-                            prepend_key=False,
-                            zone_id=zone.id,
-                            **attrs)
+        return self._create(
+            _zone_export.ZoneExport,
+            base_path='/zones/%(zone_id)s/tasks/export',
+            prepend_key=False,
+            zone_id=zone.id,
+            **attrs,
+        )
 
     def get_zone_export(self, zone_export):
         """Get a zone export record
 
         :param zone: The value can be the ID of a zone import
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
         :returns: ZoneExport instance.
         :rtype: :class:`~openstack.dns.v2.zone_export.ZoneExport`
         """
@@ -337,18 +364,21 @@ class Proxy(proxy.Proxy):
         """Get a zone export record as text
 
         :param zone: The value can be the ID of a zone import
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
         :returns: ZoneExport instance.
         :rtype: :class:`~openstack.dns.v2.zone_export.ZoneExport`
         """
-        return self._get(_zone_export.ZoneExport, zone_export,
-                         base_path='/zones/tasks/export/%(id)s/export')
+        return self._get(
+            _zone_export.ZoneExport,
+            zone_export,
+            base_path='/zones/tasks/export/%(id)s/export',
+        )
 
     def delete_zone_export(self, zone_export, ignore_missing=True):
         """Delete a zone export
 
         :param zone_export: The value can be the ID of a zone import
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be raised when
             the zone does not exist.
@@ -357,8 +387,9 @@ class Proxy(proxy.Proxy):
 
         :returns: None
         """
-        return self._delete(_zone_export.ZoneExport, zone_export,
-                            ignore_missing=ignore_missing)
+        return self._delete(
+            _zone_export.ZoneExport, zone_export, ignore_missing=ignore_missing
+        )
 
     # ======== FloatingIPs ========
     def floating_ips(self, **query):
@@ -382,8 +413,8 @@ class Proxy(proxy.Proxy):
         """Get a Floating IP
 
         :param floating_ip: The value can be the ID of a floating ip
-             or a :class:`~openstack.dns.v2.floating_ip.FloatingIP` instance.
-             The ID is in format "region_name:floatingip_id"
+            or a :class:`~openstack.dns.v2.floating_ip.FloatingIP` instance.
+            The ID is in format "region_name:floatingip_id"
         :returns: FloatingIP instance.
         :rtype: :class:`~openstack.dns.v2.floating_ip.FloatingIP`
         """
@@ -401,6 +432,17 @@ class Proxy(proxy.Proxy):
         """
         return self._update(_fip.FloatingIP, floating_ip, **attrs)
 
+    def unset_floating_ip(self, floating_ip):
+        """Unset a Floating IP PTR record
+        :param floating_ip: ID for the floatingip associated with the
+            project.
+        :returns: FloatingIP PTR record.
+        :rtype: :class:`~openstack.dns.v2.fip.FloatipgIP`
+        """
+        # concat `region:floating_ip_id` as id
+        attrs = {'ptrdname': None}
+        return self._update(_fip.FloatingIP, floating_ip, **attrs)
+
     # ======== Zone Transfer ========
     def zone_transfer_requests(self, **query):
         """Retrieve a generator of zone transfer requests
@@ -420,8 +462,8 @@ class Proxy(proxy.Proxy):
         """Get a ZoneTransfer Request info
 
         :param request: The value can be the ID of a transfer request
-             or a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
-             instance.
+            or a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
+            instance.
         :returns: Zone transfer request instance.
         :rtype: :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
         """
@@ -431,7 +473,7 @@ class Proxy(proxy.Proxy):
         """Create a new ZoneTransfer Request from attributes
 
         :param zone: The value can be the ID of a zone to be transferred
-             or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
+            or a :class:`~openstack.dns.v2.zone_export.ZoneExport` instance.
         :param dict attrs: Keyword arguments which will be used to create
             a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`,
             comprised of the properties on the ZoneTransferRequest class.
@@ -444,7 +486,8 @@ class Proxy(proxy.Proxy):
             base_path='/zones/%(zone_id)s/tasks/transfer_requests',
             prepend_key=False,
             zone_id=zone.id,
-            **attrs)
+            **attrs,
+        )
 
     def update_zone_transfer_request(self, request, **attrs):
         """Update ZoneTransfer Request attributes
@@ -456,15 +499,16 @@ class Proxy(proxy.Proxy):
 
         :rtype: :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
         """
-        return self._update(_zone_transfer.ZoneTransferRequest,
-                            request, **attrs)
+        return self._update(
+            _zone_transfer.ZoneTransferRequest, request, **attrs
+        )
 
     def delete_zone_transfer_request(self, request, ignore_missing=True):
         """Delete a ZoneTransfer Request
 
         :param request: The value can be the ID of a zone transfer request
-             or a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
-             instance.
+            or a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
+            instance.
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be raised when
             the zone does not exist.
@@ -473,8 +517,11 @@ class Proxy(proxy.Proxy):
 
         :returns: None
         """
-        return self._delete(_zone_transfer.ZoneTransferRequest, request,
-                            ignore_missing=ignore_missing)
+        return self._delete(
+            _zone_transfer.ZoneTransferRequest,
+            request,
+            ignore_missing=ignore_missing,
+        )
 
     def zone_transfer_accepts(self, **query):
         """Retrieve a generator of zone transfer accepts
@@ -494,8 +541,8 @@ class Proxy(proxy.Proxy):
         """Get a ZoneTransfer Accept info
 
         :param request: The value can be the ID of a transfer accept
-             or a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferAccept`
-             instance.
+            or a :class:`~openstack.dns.v2.zone_transfer.ZoneTransferAccept`
+            instance.
         :returns: Zone transfer request instance.
         :rtype: :class:`~openstack.dns.v2.zone_transfer.ZoneTransferAccept`
         """
@@ -512,13 +559,141 @@ class Proxy(proxy.Proxy):
         """
         return self._create(_zone_transfer.ZoneTransferAccept, **attrs)
 
+    # ======== Zone Shares ========
+    def zone_shares(self, zone, **query):
+        """Retrieve a generator of zone sharess
+
+        :param zone: The zone ID or a
+            :class:`~openstack.dns.v2.zone.Zone` instance
+        :param dict query: Optional query parameters to be sent to limit the
+                           resources being returned.
+
+                           * `target_project_id`: The target project ID field.
+
+        :returns: A generator of zone shares
+            :class:`~openstack.dns.v2.zone_share.ZoneShare` instances.
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._list(_zone_share.ZoneShare, zone_id=zone_obj.id, **query)
+
+    def get_zone_share(self, zone, zone_share):
+        """Get a zone share
+
+        :param zone: The value can be the ID of a zone
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
+        :param zone_share: The zone_share can be either the ID of the zone
+            share or a :class:`~openstack.dns.v2.zone_share.ZoneShare` instance
+            that the zone share belongs to.
+
+        :returns: ZoneShare instance.
+        :rtype: :class:`~openstack.dns.v2.zone_share.ZoneShare`
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._get(
+            _zone_share.ZoneShare, zone_share, zone_id=zone_obj.id
+        )
+
+    def find_zone_share(self, zone, zone_share_id, ignore_missing=True):
+        """Find a single zone share
+
+        :param zone: The value can be the ID of a zone
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
+        :param zone_share_id: The zone share ID
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised
+            when the zone share does not exist.
+            When set to ``True``,  None will be returned when attempting to
+            find a nonexistent zone share.
+
+        :returns: :class:`~openstack.dns.v2.zone_share.ZoneShare`
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._find(
+            _zone_share.ZoneShare,
+            zone_share_id,
+            ignore_missing=ignore_missing,
+            zone_id=zone_obj.id,
+        )
+
+    def create_zone_share(self, zone, **attrs):
+        """Create a new zone share from attributes
+
+        :param zone: The zone ID or a
+            :class:`~openstack.dns.v2.zone.Zone` instance
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.dns.v2.zone_share.ZoneShare`,
+            comprised of the properties on the ZoneShare class.
+
+        :returns: The results of zone share creation
+        :rtype: :class:`~openstack.dns.v2.zone_share.ZoneShare`
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._create(
+            _zone_share.ZoneShare, zone_id=zone_obj.id, **attrs
+        )
+
+    def delete_zone_share(self, zone, zone_share, ignore_missing=True):
+        """Delete a zone share
+
+        :param zone: The zone ID or a
+            :class:`~openstack.dns.v2.zone.Zone` instance
+        :param zone_share: The zone_share can be either the ID of the zone
+            share or a :class:`~openstack.dns.v2.zone_share.ZoneShare` instance
+            that the zone share belongs to.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the zone share does not exist.
+            When set to ``True``, no exception will be set when attempting to
+            delete a nonexistent zone share.
+
+        :returns: ``None``
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        self._delete(
+            _zone_share.ZoneShare,
+            zone_share,
+            ignore_missing=ignore_missing,
+            zone_id=zone_obj.id,
+        )
+
     def _get_cleanup_dependencies(self):
         # DNS may depend on floating ip
-        return {
-            'dns': {
-                'before': ['network']
-            }
-        }
+        return {'dns': {'before': ['network']}}
 
-    def _service_cleanup(self, dry_run=True, status_queue=False):
-        pass
+    def _service_cleanup(
+        self,
+        dry_run=True,
+        client_status_queue=False,
+        identified_resources=None,
+        filters=None,
+        resource_evaluation_fn=None,
+        skip_resources=None,
+    ):
+        if not self.should_skip_resource_cleanup("zone", skip_resources):
+            # Delete all zones
+            for obj in self.zones():
+                self._service_cleanup_del_res(
+                    self.delete_zone,
+                    obj,
+                    dry_run=dry_run,
+                    client_status_queue=client_status_queue,
+                    identified_resources=identified_resources,
+                    filters=filters,
+                    resource_evaluation_fn=resource_evaluation_fn,
+                )
+
+        if not self.should_skip_resource_cleanup(
+            "floating_ip", skip_resources
+        ):
+            # Unset all floatingIPs
+            # NOTE: FloatingIPs are not cleaned when filters are set
+            for obj in self.floating_ips():
+                self._service_cleanup_del_res(
+                    self.unset_floating_ip,
+                    obj,
+                    dry_run=dry_run,
+                    client_status_queue=client_status_queue,
+                    identified_resources=identified_resources,
+                    filters=filters,
+                    resource_evaluation_fn=resource_evaluation_fn,
+                )
