@@ -12,6 +12,7 @@
 
 import os
 import time
+import typing as ty
 import warnings
 
 from openstack import exceptions
@@ -20,6 +21,7 @@ from openstack.image.v2 import image as _image
 from openstack.image.v2 import member as _member
 from openstack.image.v2 import metadef_namespace as _metadef_namespace
 from openstack.image.v2 import metadef_object as _metadef_object
+from openstack.image.v2 import metadef_property as _metadef_property
 from openstack.image.v2 import metadef_resource_type as _metadef_resource_type
 from openstack.image.v2 import metadef_schema as _metadef_schema
 from openstack.image.v2 import schema as _schema
@@ -341,8 +343,6 @@ class Proxy(proxy.Proxy):
             image_kwargs['name'] = name
             image = self._create(_image.Image, **image_kwargs)
 
-        self._connection._get_cache(None).invalidate()
-
         return image
 
     def import_image(
@@ -603,7 +603,7 @@ class Proxy(proxy.Proxy):
             )
 
     def _make_v2_image_params(self, meta, properties):
-        ret = {}
+        ret: ty.Dict = {}
         for k, v in iter(properties.items()):
             if k in _INT_PROPERTIES:
                 ret[k] = int(v)
@@ -734,7 +734,6 @@ class Proxy(proxy.Proxy):
         }
 
         glance_task = self.create_task(**task_args)
-        self._connection.list_images.invalidate(self)
         if wait:
             start = time.time()
 
@@ -771,7 +770,6 @@ class Proxy(proxy.Proxy):
                 # Clean up after ourselves. The object we created is not
                 # needed after the import is done.
                 self._connection.delete_object(container, name)
-                self._connection.list_images.invalidate(self)
             return image
         else:
             return glance_task
@@ -964,8 +962,6 @@ class Proxy(proxy.Proxy):
 
         self.update_image(image, **img_props)
 
-        self._connection.list_images.invalidate(self._connection)
-
         return True
 
     def add_tag(self, image, tag):
@@ -1403,6 +1399,132 @@ class Proxy(proxy.Proxy):
             **query,
         )
 
+    # ====== METADEF PROPERTY ======
+    def create_metadef_property(self, metadef_namespace, **attrs):
+        """Create a metadef property
+
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_property.MetadefNamespace`
+            instance
+        :param attrs: The attributes to create on the metadef property
+            represented by ``metadef_property``.
+
+        :returns: The created metadef property
+        :rtype: :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        return self._create(
+            _metadef_property.MetadefProperty,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
+    def update_metadef_property(
+        self, metadef_property, metadef_namespace, **attrs
+    ):
+        """Update a metadef property
+
+        :param metadef_property: The value can be either the name of metadef
+            property or an
+            :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+            instance.
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+        :param attrs: The attributes to update on the metadef property
+            represented by ``metadef_property``.
+
+        :returns: The updated metadef property
+        :rtype: :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        metadef_property = resource.Resource._get_id(metadef_property)
+        return self._update(
+            _metadef_property.MetadefProperty,
+            metadef_property,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
+    def delete_metadef_property(
+        self, metadef_property, metadef_namespace, ignore_missing=True
+    ):
+        """Delete a metadef property
+
+        :param metadef_property: The value can be either the name of metadef
+            property or an
+            :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+            instance
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+        :param bool ignore_missing: When set to
+            ``False`` :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the instance does not exist. When set to ``True``,
+            no exception will be set when attempting to delete a nonexistent
+            instance.
+
+        :returns: ``None``
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        metadef_property = resource.Resource._get_id(metadef_property)
+        return self._delete(
+            _metadef_property.MetadefProperty,
+            metadef_property,
+            namespace_name=namespace_name,
+            ignore_missing=ignore_missing,
+        )
+
+    def metadef_properties(self, metadef_namespace, **query):
+        """Return a generator of metadef properties
+
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+        :param kwargs query: Optional query parameters to be sent to limit
+            the resources being returned.
+
+        :returns: A generator of property objects
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        return self._list(
+            _metadef_property.MetadefProperty,
+            requires_id=False,
+            namespace_name=namespace_name,
+            **query,
+        )
+
+    def get_metadef_property(
+        self, metadef_property, metadef_namespace, **query
+    ):
+        """Get a single metadef property
+
+        :param metadef_property: The value can be either the name of metadef
+            property or an
+            :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+            instance.
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+
+        :returns: One
+            :class:`~~openstack.image.v2.metadef_property.MetadefProperty`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        return self._get(
+            _metadef_property.MetadefProperty,
+            metadef_property,
+            namespace_name=namespace_name,
+            **query,
+        )
+
     # ====== SCHEMAS ======
     def get_images_schema(self):
         """Get images schema
