@@ -10,12 +10,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack import exceptions
 from openstack import resource
 from openstack import utils
 
 
 class Agent(resource.Resource):
     """Neutron agent extension."""
+
     resource_key = 'agent'
     resources_key = 'agents'
     base_path = '/agents'
@@ -31,9 +33,14 @@ class Agent(resource.Resource):
 
     # NOTE: We skip query for JSON fields and datetime fields
     _query_mapping = resource.QueryParameters(
-        'agent_type', 'availability_zone', 'binary', 'description', 'host',
+        'agent_type',
+        'availability_zone',
+        'binary',
+        'description',
+        'host',
         'topic',
-        is_admin_state_up='admin_state_up', is_alive='alive',
+        is_admin_state_up='admin_state_up',
+        is_alive='alive',
     )
 
     # Properties
@@ -84,8 +91,9 @@ class Agent(resource.Resource):
 
     def remove_agent_from_network(self, session, network_id):
         body = {'network_id': network_id}
-        url = utils.urljoin(self.base_path, self.id, 'dhcp-networks',
-                            network_id)
+        url = utils.urljoin(
+            self.base_path, self.id, 'dhcp-networks', network_id
+        )
         session.delete(url, json=body)
 
     def add_router_to_agent(self, session, router):
@@ -99,6 +107,18 @@ class Agent(resource.Resource):
         url = utils.urljoin(self.base_path, self.id, 'l3-routers', router)
         session.delete(url, json=body)
 
+    def get_bgp_speakers_hosted_by_dragent(self, session):
+        """List BGP speakers hosted by a Dynamic Routing Agent
+
+        :param session: The session to communicate through.
+        :type session: :class:`~keystoneauth1.adapter.Adapter`
+        """
+        url = utils.urljoin(self.base_path, self.id, 'bgp-drinstances')
+        resp = session.get(url)
+        exceptions.raise_from_response(resp)
+        self._body.attributes.update(resp.json())
+        return resp.json()
+
 
 class NetworkHostingDHCPAgent(Agent):
     resource_key = 'agent'
