@@ -9,12 +9,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+from openstack.common import tag
 from openstack.network.v2 import _base
 from openstack import resource
 
 
-class SecurityGroupRule(_base.NetworkResource, resource.TagMixin):
+class SecurityGroupRule(_base.NetworkResource, tag.TagMixin):
     resource_key = 'security_group_rule'
     resources_key = 'security_group_rules'
     base_path = '/security-group-rules'
@@ -27,16 +27,23 @@ class SecurityGroupRule(_base.NetworkResource, resource.TagMixin):
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
-        'description', 'direction', 'id', 'protocol',
-        'remote_group_id', 'security_group_id',
+        'description',
+        'direction',
+        'id',
+        'protocol',
+        'remote_group_id',
+        'security_group_id',
         'remote_address_group_id',
-        'port_range_max', 'port_range_min',
-        'remote_ip_prefix', 'revision_number',
-        'project_id', 'tenant_id',
-        'sort_dir', 'sort_key',
+        'port_range_max',
+        'port_range_min',
+        'remote_ip_prefix',
+        'revision_number',
+        'project_id',
+        'tenant_id',
+        'sort_dir',
+        'sort_key',
         ether_type='ethertype',
-        **resource.TagMixin._tag_query_parameters
-
+        **tag.TagMixin._tag_query_parameters
     )
 
     # Properties
@@ -69,28 +76,29 @@ class SecurityGroupRule(_base.NetworkResource, resource.TagMixin):
     protocol = resource.Body('protocol')
     #: The remote security group ID to be associated with this security
     #: group rule. You can specify either ``remote_group_id`` or
-    #: ``remote_address_group_id`` or ``remote_ip_prefix`` in the request body.
+    #: ``remote_address_group_id`` or ``remote_ip_prefix``.
     remote_group_id = resource.Body('remote_group_id')
     #: The remote address group ID to be associated with this security
     #: group rule. You can specify either ``remote_group_id`` or
-    #: ``remote_address_group_id`` or ``remote_ip_prefix`` in the request body.
+    #: ``remote_address_group_id`` or ``remote_ip_prefix``.
     remote_address_group_id = resource.Body('remote_address_group_id')
     #: The remote IP prefix to be associated with this security group rule.
     #: You can specify either ``remote_group_id`` or
-    # ``remote_address_group_id``or ``remote_ip_prefix`` in the request body.
-    # This attribute matches the specified IP prefix as the source IP address
-    # of the IP packet.
+    #: ``remote_address_group_id`` or ``remote_ip_prefix``.
+    #: This attribute matches the specified IP prefix as the source or
+    #: destination IP address of the IP packet depending on direction.
     remote_ip_prefix = resource.Body('remote_ip_prefix')
     #: The security group ID to associate with this security group rule.
     security_group_id = resource.Body('security_group_id')
     #: The ID of the project this security group rule is associated with.
-    tenant_id = resource.Body('tenant_id')
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: Timestamp when the security group rule was last updated.
     updated_at = resource.Body('updated_at')
 
     def _prepare_request(self, *args, **kwargs):
         _request = super(SecurityGroupRule, self)._prepare_request(
-            *args, **kwargs)
+            *args, **kwargs
+        )
         # Old versions of Neutron do not handle being passed a
         # remote_address_group_id and raise and error.  Remove it from
         # the body if it is blank.
