@@ -35,6 +35,10 @@ EXPIRES_ISO8601_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
 SHORT_EXPIRES_ISO8601_FORMAT = '%Y-%m-%d'
 
 
+def _get_expiration(expiration):
+    return int(time.time() + expiration)
+
+
 class Proxy(proxy.Proxy):
     _resource_registry = {
         "account": _account.Account,
@@ -390,7 +394,8 @@ class Proxy(proxy.Proxy):
         :param metadata: This dict will get changed into headers that set
             metadata of the object
 
-        :raises: ``OpenStackCloudException`` on operation error.
+        :raises: ``:class:`~openstack.exceptions.SDKException``` on operation
+            error.
         """
         if data is not None and filename:
             raise ValueError(
@@ -764,15 +769,17 @@ class Proxy(proxy.Proxy):
         try:
             # caps = self.get_object_capabilities()
             caps = self.get_info()
-        except exceptions.SDKException as e:
-            if e.response.status_code in (404, 412):
-                server_max_file_size = DEFAULT_MAX_FILE_SIZE
-                self._connection.log.info(
-                    "Swift capabilities not supported. "
-                    "Using default max file size."
-                )
-            else:
-                raise
+        except (
+            exceptions.NotFoundException,
+            exceptions.PreconditionFailedException,
+        ):
+            server_max_file_size = DEFAULT_MAX_FILE_SIZE
+            self._connection.log.info(
+                "Swift capabilities not supported. "
+                "Using default max file size."
+            )
+        except exceptions.SDKException:
+            raise
         else:
             server_max_file_size = caps.swift.get('max_file_size', 0)
             min_segment_size = caps.slo.get('min_segment_size', 0)
@@ -913,7 +920,7 @@ class Proxy(proxy.Proxy):
             raise exceptions.SDKException(
                 'Please use a positive <timeout> value.'
             )
-        expires = int(time.time() + int(timeout))
+        expires = _get_expiration(timeout)
 
         temp_url_key = self._check_temp_url_key(
             container=container, temp_url_key=temp_url_key
@@ -930,8 +937,7 @@ class Proxy(proxy.Proxy):
             max_upload_count,
             expires,
         )
-        data = data.encode('utf8')
-        sig = hmac.new(temp_url_key, data, sha1).hexdigest()
+        sig = hmac.new(temp_url_key, data.encode(), sha1).hexdigest()
 
         return (expires, sig)
 
@@ -987,18 +993,17 @@ class Proxy(proxy.Proxy):
                     try:
                         t = time.strptime(seconds, f)
                     except ValueError:
-                        t = None
+                        continue
+
+                    if f == EXPIRES_ISO8601_FORMAT:
+                        timestamp = timegm(t)
                     else:
-                        if f == EXPIRES_ISO8601_FORMAT:
-                            timestamp = timegm(t)
-                        else:
-                            # Use local time if UTC designator is missing.
-                            timestamp = int(time.mktime(t))
+                        # Use local time if UTC designator is missing.
+                        timestamp = int(time.mktime(t))
 
-                        absolute = True
-                        break
-
-                if t is None:
+                    absolute = True
+                    break
+                else:
                     raise ValueError()
             else:
                 if not timestamp.is_integer():
@@ -1041,8 +1046,9 @@ class Proxy(proxy.Proxy):
                 method.upper(),
             )
 
+        expiration: float | int
         if not absolute:
-            expiration = int(time.time() + timestamp)
+            expiration = _get_expiration(timestamp)
         else:
             expiration = timestamp
 
@@ -1069,12 +1075,16 @@ class Proxy(proxy.Proxy):
         ).hexdigest()
 
         if iso8601:
-            expiration = time.strftime(
+            exp = time.strftime(
                 EXPIRES_ISO8601_FORMAT, time.gmtime(expiration)
             )
+        else:
+            exp = str(expiration)
 
         temp_url = u'{path}?temp_url_sig={sig}&temp_url_expires={exp}'.format(
-            path=path_for_body, sig=sig, exp=expiration
+            path=path_for_body,
+            sig=sig,
+            exp=exp,
         )
 
         if ip_range:
@@ -1130,19 +1140,26 @@ class Proxy(proxy.Proxy):
         identified_resources=None,
         filters=None,
         resource_evaluation_fn=None,
+        skip_resources=None,
     ):
+        if self.should_skip_resource_cleanup(
+            "container", skip_resources
+        ) or self.should_skip_resource_cleanup("object", skip_resources):
+            return
+
         is_bulk_delete_supported = False
-        bulk_delete_max_per_request = None
+        bulk_delete_max_per_request = 1
         try:
             caps = self.get_info()
         except exceptions.SDKException:
             pass
         else:
-            bulk_delete = caps.swift.get("bulk_delete", {})
-            is_bulk_delete_supported = bulk_delete is not None
-            bulk_delete_max_per_request = bulk_delete.get(
-                "max_deletes_per_request", 100
-            )
+            bulk_delete = caps.get("bulk_delete")
+            if bulk_delete is not None:
+                is_bulk_delete_supported = True
+                bulk_delete_max_per_request = bulk_delete.get(
+                    "max_deletes_per_request", 10000
+                )
 
         elements = []
         for cont in self.containers():
@@ -1159,18 +1176,20 @@ class Proxy(proxy.Proxy):
                     resource_evaluation_fn=resource_evaluation_fn,
                 )
                 if need_delete:
-                    if not is_bulk_delete_supported and not dry_run:
-                        self.delete_object(obj, cont)
-                    else:
+                    if dry_run:
+                        continue
+                    elif is_bulk_delete_supported:
                         elements.append(f"{cont.name}/{obj.name}")
                         if len(elements) >= bulk_delete_max_per_request:
-                            self._bulk_delete(elements, dry_run=dry_run)
+                            self._bulk_delete(elements)
                             elements.clear()
+                    else:
+                        self.delete_object(obj, cont)
                 else:
                     objects_remaining = True
 
             if len(elements) > 0:
-                self._bulk_delete(elements, dry_run=dry_run)
+                self._bulk_delete(elements)
                 elements.clear()
 
             # Eventually delete container itself
@@ -1185,14 +1204,13 @@ class Proxy(proxy.Proxy):
                     resource_evaluation_fn=resource_evaluation_fn,
                 )
 
-    def _bulk_delete(self, elements, dry_run=False):
+    def _bulk_delete(self, elements):
         data = "\n".join([parse.quote(x) for x in elements])
-        if not dry_run:
-            self.delete(
-                "?bulk-delete",
-                data=data,
-                headers={
-                    'Content-Type': 'text/plain',
-                    'Accept': 'application/json',
-                },
-            )
+        self.delete(
+            "?bulk-delete",
+            data=data,
+            headers={
+                'Content-Type': 'text/plain',
+                'Accept': 'application/json',
+            },
+        )
