@@ -11,11 +11,7 @@
 # under the License.
 
 import functools
-from typing import Generator
-from typing import Generic
-from typing import Optional
-from typing import Type
-from typing import TypeVar
+import typing as ty
 import urllib
 from urllib.parse import urlparse
 
@@ -24,7 +20,7 @@ try:
 
     JSONDecodeError = simplejson.scanner.JSONDecodeError
 except ImportError:
-    JSONDecodeError = ValueError
+    JSONDecodeError = ValueError  # type: ignore
 import iso8601
 import jmespath
 from keystoneauth1 import adapter
@@ -33,7 +29,8 @@ from openstack import _log
 from openstack import exceptions
 from openstack import resource
 
-T = TypeVar('T')
+
+ResourceType = ty.TypeVar('ResourceType', bound=resource.Resource)
 
 
 # The _check_resource decorator is used on Proxy methods to ensure that
@@ -74,17 +71,17 @@ def normalize_metric_name(name):
     return name
 
 
-class Proxy(adapter.Adapter, Generic[T]):
+class Proxy(adapter.Adapter):
     """Represents a service."""
 
-    retriable_status_codes = None
+    retriable_status_codes: ty.Optional[ty.List[int]] = None
     """HTTP status codes that should be retried by default.
 
     The number of retries is defined by the configuration in parameters called
     ``<service-type>_status_code_retries``.
     """
 
-    _resource_registry = dict()
+    _resource_registry: ty.Dict[str, ty.Type[resource.Resource]] = {}
     """Registry of the supported resourses.
 
     Dictionary of resource names (key) types (value).
@@ -100,14 +97,14 @@ class Proxy(adapter.Adapter, Generic[T]):
         influxdb_config=None,
         influxdb_client=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         # NOTE(dtantsur): keystoneauth defaults retriable_status_codes to None,
         # override it with a class-level value.
         kwargs.setdefault(
             'retriable_status_codes', self.retriable_status_codes
         )
-        super(Proxy, self).__init__(session=session, *args, **kwargs)
+        super().__init__(session=session, *args, **kwargs)
         self._statsd_client = statsd_client
         self._statsd_prefix = statsd_prefix
         self._prometheus_counter = prometheus_counter
@@ -144,7 +141,7 @@ class Proxy(adapter.Adapter, Generic[T]):
         connect_retries=1,
         global_request_id=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         conn = self._get_connection()
         if not global_request_id:
@@ -173,14 +170,14 @@ class Proxy(adapter.Adapter, Generic[T]):
                 # Get from cache or execute and cache
                 response = conn._cache.get_or_create(
                     key=key,
-                    creator=super(Proxy, self).request,
+                    creator=super().request,
                     creator_args=(
                         [url, method],
                         dict(
                             connect_retries=connect_retries,
                             raise_exc=raise_exc,
                             global_request_id=global_request_id,
-                            **kwargs
+                            **kwargs,
                         ),
                     ),
                     expiration_time=expiration_time,
@@ -190,13 +187,13 @@ class Proxy(adapter.Adapter, Generic[T]):
                 # asked for cache bypass
                 self._invalidate_cache(conn, key_prefix)
                 # Pass through the API request bypassing cache
-                response = super(Proxy, self).request(
+                response = super().request(
                     url,
                     method,
                     connect_retries=connect_retries,
                     raise_exc=raise_exc,
                     global_request_id=global_request_id,
-                    **kwargs
+                    **kwargs,
                 )
 
             for h in response.history:
@@ -211,6 +208,7 @@ class Proxy(adapter.Adapter, Generic[T]):
             self._report_stats(None, url, method, e)
             raise
 
+    # TODO(stephenfin): service_type is unused and should be dropped
     @functools.lru_cache(maxsize=256)
     def _extract_name(self, url, service_type=None, project_id=None):
         """Produce a key name to use in logging/metrics from the URL path.
@@ -420,12 +418,6 @@ class Proxy(adapter.Adapter, Generic[T]):
         except Exception:
             self.log.exception('Error writing statistics to InfluxDB')
 
-    def _version_matches(self, version):
-        api_version = self.get_api_major_version()
-        if api_version:
-            return api_version[0] == version
-        return False
-
     def _get_connection(self):
         """Get the Connection object associated with this Proxy.
 
@@ -437,8 +429,9 @@ class Proxy(adapter.Adapter, Generic[T]):
             self, '_connection', getattr(self.session, '_sdk_connection', None)
         )
 
-    def _get_resource(self, resource_type: Type[T], value,
-                      **attrs) -> T:
+    def _get_resource(
+        self, resource_type: ty.Type[ResourceType], value, **attrs
+    ) -> ResourceType:
         """Get a resource object to work on
 
         :param resource_type: The type of resource to operate on. This should
@@ -484,8 +477,45 @@ class Proxy(adapter.Adapter, Generic[T]):
             value = resource.Resource._get_id(parent)
         return value
 
-    def _find(self, resource_type: Type[T], name_or_id, ignore_missing=True,
-              **attrs) -> Optional[T]:
+    @ty.overload
+    def _find(
+        self,
+        resource_type: ty.Type[ResourceType],
+        name_or_id: str,
+        ignore_missing: ty.Literal[True] = True,
+        **attrs,
+    ) -> ty.Optional[ResourceType]:
+        ...
+
+    @ty.overload
+    def _find(
+        self,
+        resource_type: ty.Type[ResourceType],
+        name_or_id: str,
+        ignore_missing: ty.Literal[False],
+        **attrs,
+    ) -> ResourceType:
+        ...
+
+    # excuse the duplication here: it's mypy's fault
+    # https://github.com/python/mypy/issues/14764
+    @ty.overload
+    def _find(
+        self,
+        resource_type: ty.Type[ResourceType],
+        name_or_id: str,
+        ignore_missing: bool,
+        **attrs,
+    ) -> ty.Optional[ResourceType]:
+        ...
+
+    def _find(
+        self,
+        resource_type: ty.Type[ResourceType],
+        name_or_id: str,
+        ignore_missing: bool = True,
+        **attrs,
+    ) -> ty.Optional[ResourceType]:
         """Find a resource
 
         :param name_or_id: The name or ID of a resource to find.
@@ -505,8 +535,13 @@ class Proxy(adapter.Adapter, Generic[T]):
         )
 
     @_check_resource(strict=False)
-    def _delete(self, resource_type: Type[T], value, ignore_missing=True,
-                **attrs):
+    def _delete(
+        self,
+        resource_type: ty.Type[ResourceType],
+        value,
+        ignore_missing=True,
+        **attrs,
+    ) -> ty.Optional[ResourceType]:
         """Delete a resource
 
         :param resource_type: The type of resource to delete. This should
@@ -542,8 +577,13 @@ class Proxy(adapter.Adapter, Generic[T]):
         return rv
 
     @_check_resource(strict=False)
-    def _update(self, resource_type: Type[T], value, base_path=None,
-                **attrs) -> T:
+    def _update(
+        self,
+        resource_type: ty.Type[ResourceType],
+        value,
+        base_path=None,
+        **attrs,
+    ) -> ResourceType:
         """Update a resource
 
         :param resource_type: The type of resource to update.
@@ -567,7 +607,12 @@ class Proxy(adapter.Adapter, Generic[T]):
         res = self._get_resource(resource_type, value, **attrs)
         return res.commit(self, base_path=base_path)
 
-    def _create(self, resource_type: Type[T], base_path=None, **attrs):
+    def _create(
+        self,
+        resource_type: ty.Type[ResourceType],
+        base_path=None,
+        **attrs,
+    ) -> ResourceType:
         """Create a resource from attributes
 
         :param resource_type: The type of resource to create.
@@ -587,12 +632,23 @@ class Proxy(adapter.Adapter, Generic[T]):
         :returns: The result of the ``create``
         :rtype: :class:`~openstack.resource.Resource`
         """
+        # Check for attributes whose names conflict with the parameters
+        # specified in the method.
+        conflicting_attrs = attrs.get('__conflicting_attrs', {})
+        if conflicting_attrs:
+            for k, v in conflicting_attrs.items():
+                attrs[k] = v
+            attrs.pop('__conflicting_attrs')
         conn = self._get_connection()
         res = resource_type.new(connection=conn, **attrs)
         return res.create(self, base_path=base_path)
 
-    def _bulk_create(self, resource_type: Type[T], data, base_path=None
-                     ) -> Generator[T, None, None]:
+    def _bulk_create(
+        self,
+        resource_type: ty.Type[ResourceType],
+        data,
+        base_path=None,
+    ) -> ty.Generator[ResourceType, None, None]:
         """Create a resource from attributes
 
         :param resource_type: The type of resource to create.
@@ -614,14 +670,14 @@ class Proxy(adapter.Adapter, Generic[T]):
 
     @_check_resource(strict=False)
     def _get(
-            self,
-            resource_type: Type[T],
-            value=None,
-            requires_id=True,
-            base_path=None,
-            skip_cache=False,
-            **attrs
-    ):
+        self,
+        resource_type: ty.Type[ResourceType],
+        value=None,
+        requires_id=True,
+        base_path=None,
+        skip_cache=False,
+        **attrs,
+    ) -> ResourceType:
         """Fetch a resource
 
         :param resource_type: The type of resource to get.
@@ -657,13 +713,13 @@ class Proxy(adapter.Adapter, Generic[T]):
         )
 
     def _list(
-            self,
-            resource_type: Type[T],
-            paginated=True,
-            base_path=None,
-            jmespath_filters=None,
-            **attrs
-    ) -> Generator[T, None, None]:
+        self,
+        resource_type: ty.Type[ResourceType],
+        paginated=True,
+        base_path=None,
+        jmespath_filters=None,
+        **attrs,
+    ) -> ty.Generator[ResourceType, None, None]:
         """List a resource
 
         :param resource_type: The type of resource to list. This should
@@ -689,10 +745,8 @@ class Proxy(adapter.Adapter, Generic[T]):
             :class:`~openstack.resource.Resource` that doesn't match
             the ``resource_type``.
         """
-
         data = resource_type.list(
-            self, paginated=paginated, base_path=base_path,
-            **attrs
+            self, paginated=paginated, base_path=base_path, **attrs
         )
 
         if jmespath_filters and isinstance(jmespath_filters, str):
@@ -700,8 +754,13 @@ class Proxy(adapter.Adapter, Generic[T]):
 
         return data
 
-    def _head(self, resource_type: Type[T], value=None, base_path=None,
-              **attrs):
+    def _head(
+        self,
+        resource_type: ty.Type[ResourceType],
+        value=None,
+        base_path=None,
+        **attrs,
+    ) -> ResourceType:
         """Retrieve a resource's header
 
         :param resource_type: The type of resource to retrieve.
@@ -734,6 +793,7 @@ class Proxy(adapter.Adapter, Generic[T]):
         identified_resources=None,
         filters=None,
         resource_evaluation_fn=None,
+        skip_resources=None,
     ):
         return None
 
@@ -812,7 +872,23 @@ class Proxy(adapter.Adapter, Generic[T]):
         else:
             return False
 
+    def should_skip_resource_cleanup(self, resource=None, skip_resources=None):
+        if resource is None or skip_resources is None:
+            return False
 
+        resource_name = f"{self.service_type.replace('-', '_')}.{resource}"
+
+        if resource_name in skip_resources:
+            self.log.debug(
+                f"Skipping resource {resource_name} " "in project cleanup"
+            )
+            return True
+
+        return False
+
+
+# TODO(stephenfin): Remove this and all users. Use of this generally indicates
+# a missing Resource type.
 def _json_response(response, result_key=None, error_message=None):
     """Temporary method to use to bridge from ShadeAdapter to SDK calls."""
     exceptions.raise_from_response(response, error_message=error_message)
@@ -830,11 +906,3 @@ def _json_response(response, result_key=None, error_message=None):
     except JSONDecodeError:
         return response
     return result_json
-
-
-class _ShadeAdapter(Proxy):
-    """Wrapper for shade methods that expect json unpacking."""
-
-    def request(self, url, method, error_message=None, **kwargs):
-        response = super(_ShadeAdapter, self).request(url, method, **kwargs)
-        return _json_response(response, error_message=error_message)
