@@ -14,16 +14,15 @@
 test_compute
 ----------------------------------
 
-Functional tests for `shade` compute methods.
+Functional tests for compute methods.
 """
 
 import datetime
 
 from fixtures import TimeoutException
 
-from openstack.cloud import exc
+from openstack import exceptions
 from openstack.tests.functional import base
-from openstack.tests.functional.cloud.util import pick_flavor
 from openstack import utils
 
 
@@ -34,11 +33,6 @@ class TestCompute(base.BaseFunctionalTest):
         self.TIMEOUT_SCALING_FACTOR = 1.5
 
         super(TestCompute, self).setUp()
-        self.flavor = pick_flavor(
-            self.user_cloud.list_flavors(get_extra=False))
-        if self.flavor is None:
-            self.assertFalse('no sensible flavor available')
-        self.image = self.pick_image()
         self.server_name = self.getUniqueString()
 
     def _cleanup_servers_and_volumes(self, server_name):
@@ -58,14 +52,15 @@ class TestCompute(base.BaseFunctionalTest):
             for volume in volumes:
                 if volume.status != 'deleting':
                     self.user_cloud.delete_volume(volume.id, wait=True)
-        except (exc.OpenStackCloudTimeout, TimeoutException):
+        except (exceptions.ResourceTimeout, TimeoutException):
             # Ups, some timeout occured during process of deletion server
             # or volumes, so now we will try to call delete each of them
             # once again and we will try to live with it
             self.user_cloud.delete_server(server.name)
             for volume in volumes:
                 self.operator_cloud.delete_volume(
-                    volume.id, wait=False, force=True)
+                    volume.id, wait=False, force=True
+                )
 
     def test_create_and_delete_server(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -73,14 +68,17 @@ class TestCompute(base.BaseFunctionalTest):
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
+            wait=True,
+        )
         self.assertEqual(self.server_name, server['name'])
         self.assertEqual(self.image.id, server['image']['id'])
-        self.assertEqual(self.flavor.id, server['flavor']['id'])
+        self.assertEqual(self.flavor.name, server['flavor']['original_name'])
         self.assertIsNotNone(server['adminPass'])
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_create_and_delete_server_auto_ip_delete_ips(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -89,23 +87,27 @@ class TestCompute(base.BaseFunctionalTest):
             image=self.image,
             flavor=self.flavor,
             auto_ip=True,
-            wait=True)
+            wait=True,
+        )
         self.assertEqual(self.server_name, server['name'])
         self.assertEqual(self.image.id, server['image']['id'])
-        self.assertEqual(self.flavor.id, server['flavor']['id'])
+        self.assertEqual(self.flavor.name, server['flavor']['original_name'])
         self.assertIsNotNone(server['adminPass'])
         self.assertTrue(
             self.user_cloud.delete_server(
-                self.server_name, wait=True, delete_ips=True))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+                self.server_name, wait=True, delete_ips=True
+            )
+        )
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_attach_detach_volume(self):
         self.skipTest('Volume functional tests temporarily disabled')
         server_name = self.getUniqueString()
         self.addCleanup(self._cleanup_servers_and_volumes, server_name)
         server = self.user_cloud.create_server(
-            name=server_name, image=self.image, flavor=self.flavor,
-            wait=True)
+            name=server_name, image=self.image, flavor=self.flavor, wait=True
+        )
         volume = self.user_cloud.create_volume(1)
         vol_attachment = self.user_cloud.attach_volume(server, volume)
         for key in ('device', 'serverId', 'volumeId'):
@@ -113,6 +115,24 @@ class TestCompute(base.BaseFunctionalTest):
             self.assertTrue(vol_attachment[key])  # assert string is not empty
         self.assertIsNone(self.user_cloud.detach_volume(server, volume))
 
+    def test_attach_volume_create_snapshot(self):
+        self.skipTest('Volume functional tests temporarily disabled')
+        server_name = self.getUniqueString()
+        self.addCleanup(self._cleanup_servers_and_volumes, server_name)
+        server = self.user_cloud.create_server(
+            name=server_name, image=self.image, flavor=self.flavor, wait=True
+        )
+        volume = self.user_cloud.create_volume(1)
+        vol_attachment = self.user_cloud.attach_volume(server, volume)
+        for key in ('device', 'serverId', 'volumeId'):
+            self.assertIn(key, vol_attachment)
+            self.assertTrue(vol_attachment[key])  # assert string is not empty
+        snapshot = self.user_cloud.create_volume_snapshot(
+            volume_id=volume.id, force=True, wait=True
+        )
+        self.addCleanup(self.user_cloud.delete_volume_snapshot, snapshot['id'])
+        self.assertIsNotNone(snapshot)
+
     def test_create_and_delete_server_with_config_drive(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         server = self.user_cloud.create_server(
@@ -120,15 +140,18 @@ class TestCompute(base.BaseFunctionalTest):
             image=self.image,
             flavor=self.flavor,
             config_drive=True,
-            wait=True)
+            wait=True,
+        )
         self.assertEqual(self.server_name, server['name'])
         self.assertEqual(self.image.id, server['image']['id'])
-        self.assertEqual(self.flavor.id, server['flavor']['id'])
+        self.assertEqual(self.flavor.name, server['flavor']['original_name'])
         self.assertTrue(server['has_config_drive'])
         self.assertIsNotNone(server['adminPass'])
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_create_and_delete_server_with_config_drive_none(self):
         # check that we're not sending invalid values for config_drive
@@ -140,24 +163,29 @@ class TestCompute(base.BaseFunctionalTest):
             image=self.image,
             flavor=self.flavor,
             config_drive=None,
-            wait=True)
+            wait=True,
+        )
         self.assertEqual(self.server_name, server['name'])
         self.assertEqual(self.image.id, server['image']['id'])
-        self.assertEqual(self.flavor.id, server['flavor']['id'])
+        self.assertEqual(self.flavor.name, server['flavor']['original_name'])
         self.assertFalse(server['has_config_drive'])
         self.assertIsNotNone(server['adminPass'])
         self.assertTrue(
-            self.user_cloud.delete_server(
-                self.server_name, wait=True))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_list_all_servers(self):
+        if not self.operator_cloud:
+            self.skipTest("Operator cloud is required for this test")
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         server = self.user_cloud.create_server(
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
+            wait=True,
+        )
         # We're going to get servers from other tests, but that's ok, as long
         # as we get the server we created with the demo user.
         found_server = False
@@ -169,9 +197,10 @@ class TestCompute(base.BaseFunctionalTest):
     def test_list_all_servers_bad_permissions(self):
         # Normal users are not allowed to pass all_projects=True
         self.assertRaises(
-            exc.OpenStackCloudException,
+            exceptions.SDKException,
             self.user_cloud.list_servers,
-            all_projects=True)
+            all_projects=True,
+        )
 
     def test_create_server_image_flavor_dict(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -179,14 +208,17 @@ class TestCompute(base.BaseFunctionalTest):
             name=self.server_name,
             image={'id': self.image.id},
             flavor={'id': self.flavor.id},
-            wait=True)
+            wait=True,
+        )
         self.assertEqual(self.server_name, server['name'])
         self.assertEqual(self.image.id, server['image']['id'])
-        self.assertEqual(self.flavor.id, server['flavor']['id'])
+        self.assertEqual(self.flavor.name, server['flavor']['original_name'])
         self.assertIsNotNone(server['adminPass'])
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_get_server_console(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -194,12 +226,13 @@ class TestCompute(base.BaseFunctionalTest):
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
+            wait=True,
+        )
         # _get_server_console_output does not trap HTTP exceptions, so this
         # returning a string tests that the call is correct. Testing that
         # the cloud returns actual data in the output is out of scope.
         log = self.user_cloud._get_server_console_output(server_id=server.id)
-        self.assertTrue(isinstance(log, str))
+        self.assertIsInstance(log, str)
 
     def test_get_server_console_name_or_id(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -207,19 +240,22 @@ class TestCompute(base.BaseFunctionalTest):
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
+            wait=True,
+        )
         log = self.user_cloud.get_server_console(server=self.server_name)
-        self.assertTrue(isinstance(log, str))
+        self.assertIsInstance(log, str)
 
     def test_list_availability_zone_names(self):
         self.assertEqual(
-            ['nova'], self.user_cloud.list_availability_zone_names())
+            ['nova'], self.user_cloud.list_availability_zone_names()
+        )
 
     def test_get_server_console_bad_server(self):
         self.assertRaises(
-            exc.OpenStackCloudException,
+            exceptions.SDKException,
             self.user_cloud.get_server_console,
-            server=self.server_name)
+            server=self.server_name,
+        )
 
     def test_create_and_delete_server_with_admin_pass(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -228,26 +264,33 @@ class TestCompute(base.BaseFunctionalTest):
             image=self.image,
             flavor=self.flavor,
             admin_pass='sheiqu9loegahSh',
-            wait=True)
+            wait=True,
+        )
         self.assertEqual(self.server_name, server['name'])
         self.assertEqual(self.image.id, server['image']['id'])
-        self.assertEqual(self.flavor.id, server['flavor']['id'])
+        self.assertEqual(self.flavor.name, server['flavor']['original_name'])
         self.assertEqual(server['adminPass'], 'sheiqu9loegahSh')
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_get_image_id(self):
         self.assertEqual(
-            self.image.id, self.user_cloud.get_image_id(self.image.id))
+            self.image.id, self.user_cloud.get_image_id(self.image.id)
+        )
         self.assertEqual(
-            self.image.id, self.user_cloud.get_image_id(self.image.name))
+            self.image.id, self.user_cloud.get_image_id(self.image.name)
+        )
 
     def test_get_image_name(self):
         self.assertEqual(
-            self.image.name, self.user_cloud.get_image_name(self.image.id))
+            self.image.name, self.user_cloud.get_image_name(self.image.id)
+        )
         self.assertEqual(
-            self.image.name, self.user_cloud.get_image_name(self.image.name))
+            self.image.name, self.user_cloud.get_image_name(self.image.name)
+        )
 
     def _assert_volume_attach(self, server, volume_id=None, image=''):
         self.assertEqual(self.server_name, server['name'])
@@ -275,7 +318,8 @@ class TestCompute(base.BaseFunctionalTest):
             flavor=self.flavor,
             boot_from_volume=True,
             volume_size=1,
-            wait=True)
+            wait=True,
+        )
         volume_id = self._assert_volume_attach(server)
         volume = self.user_cloud.get_volume(volume_id)
         self.assertIsNotNone(volume)
@@ -285,7 +329,8 @@ class TestCompute(base.BaseFunctionalTest):
         self.assertTrue(self.user_cloud.delete_server(server.id, wait=True))
         self._wait_for_detach(volume.id)
         self.assertTrue(self.user_cloud.delete_volume(volume.id, wait=True))
-        self.assertIsNone(self.user_cloud.get_server(server.id))
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
         self.assertIsNone(self.user_cloud.get_volume(volume.id))
 
     def _wait_for_detach(self, volume_id):
@@ -293,13 +338,18 @@ class TestCompute(base.BaseFunctionalTest):
         # deleting a server that had had a volume attached. Yay for eventual
         # consistency!
         for count in utils.iterate_timeout(
-                60,
-                'Timeout waiting for volume {volume_id} to detach'.format(
-                    volume_id=volume_id)):
+            60,
+            'Timeout waiting for volume {volume_id} to detach'.format(
+                volume_id=volume_id
+            ),
+        ):
             volume = self.user_cloud.get_volume(volume_id)
             if volume.status in (
-                    'available', 'error',
-                    'error_restoring', 'error_extending'):
+                'available',
+                'error',
+                'error_restoring',
+                'error_extending',
+            ):
                 return
 
     def test_create_terminate_volume_image(self):
@@ -314,16 +364,19 @@ class TestCompute(base.BaseFunctionalTest):
             boot_from_volume=True,
             terminate_volume=True,
             volume_size=1,
-            wait=True)
+            wait=True,
+        )
         volume_id = self._assert_volume_attach(server)
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
         volume = self.user_cloud.get_volume(volume_id)
         # We can either get None (if the volume delete was quick), or a volume
         # that is in the process of being deleted.
         if volume:
             self.assertEqual('deleting', volume.status)
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_create_boot_from_volume_preexisting(self):
         self.skipTest('Volume functional tests temporarily disabled')
@@ -331,7 +384,8 @@ class TestCompute(base.BaseFunctionalTest):
             self.skipTest('volume service not supported by cloud')
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         volume = self.user_cloud.create_volume(
-            size=1, name=self.server_name, image=self.image, wait=True)
+            size=1, name=self.server_name, image=self.image, wait=True
+        )
         self.addCleanup(self.user_cloud.delete_volume, volume.id)
         server = self.user_cloud.create_server(
             name=self.server_name,
@@ -339,10 +393,12 @@ class TestCompute(base.BaseFunctionalTest):
             flavor=self.flavor,
             boot_volume=volume,
             volume_size=1,
-            wait=True)
+            wait=True,
+        )
         volume_id = self._assert_volume_attach(server, volume_id=volume['id'])
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
         volume = self.user_cloud.get_volume(volume_id)
         self.assertIsNotNone(volume)
         self.assertEqual(volume['name'], volume['display_name'])
@@ -350,7 +406,8 @@ class TestCompute(base.BaseFunctionalTest):
         self.assertEqual([], volume['attachments'])
         self._wait_for_detach(volume.id)
         self.assertTrue(self.user_cloud.delete_volume(volume_id))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
         self.assertIsNone(self.user_cloud.get_volume(volume_id))
 
     def test_create_boot_attach_volume(self):
@@ -359,7 +416,8 @@ class TestCompute(base.BaseFunctionalTest):
             self.skipTest('volume service not supported by cloud')
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         volume = self.user_cloud.create_volume(
-            size=1, name=self.server_name, image=self.image, wait=True)
+            size=1, name=self.server_name, image=self.image, wait=True
+        )
         self.addCleanup(self.user_cloud.delete_volume, volume['id'])
         server = self.user_cloud.create_server(
             name=self.server_name,
@@ -367,18 +425,22 @@ class TestCompute(base.BaseFunctionalTest):
             image=self.image,
             boot_from_volume=False,
             volumes=[volume],
-            wait=True)
+            wait=True,
+        )
         volume_id = self._assert_volume_attach(
-            server, volume_id=volume['id'], image={'id': self.image['id']})
+            server, volume_id=volume['id'], image={'id': self.image['id']}
+        )
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
         volume = self.user_cloud.get_volume(volume_id)
         self.assertIsNotNone(volume)
         self.assertEqual(volume['name'], volume['display_name'])
         self.assertEqual([], volume['attachments'])
         self._wait_for_detach(volume.id)
         self.assertTrue(self.user_cloud.delete_volume(volume_id))
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
         self.assertIsNone(self.user_cloud.get_volume(volume_id))
 
     def test_create_boot_from_volume_preexisting_terminate(self):
@@ -387,7 +449,8 @@ class TestCompute(base.BaseFunctionalTest):
             self.skipTest('volume service not supported by cloud')
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         volume = self.user_cloud.create_volume(
-            size=1, name=self.server_name, image=self.image, wait=True)
+            size=1, name=self.server_name, image=self.image, wait=True
+        )
         server = self.user_cloud.create_server(
             name=self.server_name,
             image=None,
@@ -395,16 +458,19 @@ class TestCompute(base.BaseFunctionalTest):
             boot_volume=volume,
             terminate_volume=True,
             volume_size=1,
-            wait=True)
+            wait=True,
+        )
         volume_id = self._assert_volume_attach(server, volume_id=volume['id'])
         self.assertTrue(
-            self.user_cloud.delete_server(self.server_name, wait=True))
+            self.user_cloud.delete_server(self.server_name, wait=True)
+        )
         volume = self.user_cloud.get_volume(volume_id)
         # We can either get None (if the volume delete was quick), or a volume
         # that is in the process of being deleted.
         if volume:
             self.assertEqual('deleting', volume.status)
-        self.assertIsNone(self.user_cloud.get_server(self.server_name))
+        srv = self.user_cloud.get_server(self.server_name)
+        self.assertTrue(srv is None or srv.status.lower() == 'deleted')
 
     def test_create_image_snapshot_wait_active(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -413,9 +479,11 @@ class TestCompute(base.BaseFunctionalTest):
             image=self.image,
             flavor=self.flavor,
             admin_pass='sheiqu9loegahSh',
-            wait=True)
-        image = self.user_cloud.create_image_snapshot('test-snapshot', server,
-                                                      wait=True)
+            wait=True,
+        )
+        image = self.user_cloud.create_image_snapshot(
+            'test-snapshot', server, wait=True
+        )
         self.addCleanup(self.user_cloud.delete_image, image['id'])
         self.assertEqual('active', image['status'])
 
@@ -425,33 +493,43 @@ class TestCompute(base.BaseFunctionalTest):
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
-        self.user_cloud.set_server_metadata(self.server_name,
-                                            {'key1': 'value1',
-                                             'key2': 'value2'})
+            wait=True,
+        )
+        self.user_cloud.set_server_metadata(
+            self.server_name, {'key1': 'value1', 'key2': 'value2'}
+        )
         updated_server = self.user_cloud.get_server(self.server_name)
-        self.assertEqual(set(updated_server.metadata.items()),
-                         set({'key1': 'value1', 'key2': 'value2'}.items()))
+        self.assertEqual(
+            set(updated_server.metadata.items()),
+            set({'key1': 'value1', 'key2': 'value2'}.items()),
+        )
 
-        self.user_cloud.set_server_metadata(self.server_name,
-                                            {'key2': 'value3'})
+        self.user_cloud.set_server_metadata(
+            self.server_name, {'key2': 'value3'}
+        )
         updated_server = self.user_cloud.get_server(self.server_name)
-        self.assertEqual(set(updated_server.metadata.items()),
-                         set({'key1': 'value1', 'key2': 'value3'}.items()))
+        self.assertEqual(
+            set(updated_server.metadata.items()),
+            set({'key1': 'value1', 'key2': 'value3'}.items()),
+        )
 
         self.user_cloud.delete_server_metadata(self.server_name, ['key2'])
         updated_server = self.user_cloud.get_server(self.server_name)
-        self.assertEqual(set(updated_server.metadata.items()),
-                         set({'key1': 'value1'}.items()))
+        self.assertEqual(
+            set(updated_server.metadata.items()),
+            set({'key1': 'value1'}.items()),
+        )
 
         self.user_cloud.delete_server_metadata(self.server_name, ['key1'])
         updated_server = self.user_cloud.get_server(self.server_name)
         self.assertEqual(set(updated_server.metadata.items()), set([]))
 
         self.assertRaises(
-            exc.OpenStackCloudURINotFound,
+            exceptions.NotFoundException,
             self.user_cloud.delete_server_metadata,
-            self.server_name, ['key1'])
+            self.server_name,
+            ['key1'],
+        )
 
     def test_update_server(self):
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
@@ -459,27 +537,31 @@ class TestCompute(base.BaseFunctionalTest):
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
+            wait=True,
+        )
         server_updated = self.user_cloud.update_server(
-            self.server_name,
-            name='new_name'
+            self.server_name, name='new_name'
         )
         self.assertEqual('new_name', server_updated['name'])
 
     def test_get_compute_usage(self):
         '''Test usage functionality'''
         # Add a server so that we can know we have usage
+        if not self.operator_cloud:
+            # TODO(gtema) rework method not to require getting project
+            self.skipTest("Operator cloud is required for this test")
         self.addCleanup(self._cleanup_servers_and_volumes, self.server_name)
         self.user_cloud.create_server(
             name=self.server_name,
             image=self.image,
             flavor=self.flavor,
-            wait=True)
+            wait=True,
+        )
         start = datetime.datetime.now() - datetime.timedelta(seconds=5)
         usage = self.operator_cloud.get_compute_usage('demo', start)
         self.add_info_on_exception('usage', usage)
         self.assertIsNotNone(usage)
         self.assertIn('total_hours', usage)
-        self.assertIn('started_at', usage)
-        self.assertEqual(start.isoformat(), usage['started_at'])
+        self.assertIn('start', usage)
+        self.assertEqual(start.isoformat(), usage['start'])
         self.assertIn('location', usage)
