@@ -14,7 +14,7 @@
 test_keypairs
 ----------------------------------
 
-Functional tests for `shade` keypairs methods
+Functional tests for keypairs methods
 """
 from openstack.tests import fakes
 from openstack.tests.functional import base
