@@ -13,6 +13,8 @@ from unittest import mock
 
 from openstack.block_storage.v2 import _proxy
 from openstack.block_storage.v2 import backup
+from openstack.block_storage.v2 import capabilities
+from openstack.block_storage.v2 import limits
 from openstack.block_storage.v2 import quota_set
 from openstack.block_storage.v2 import snapshot
 from openstack.block_storage.v2 import stats
@@ -289,6 +291,21 @@ class TestBackup(TestVolumeProxy):
         )
 
 
+class TestLimit(TestVolumeProxy):
+    def test_limits_get(self):
+        self.verify_get(
+            self.proxy.get_limits,
+            limits.Limit,
+            method_args=[],
+            expected_kwargs={'requires_id': False},
+        )
+
+
+class TestCapabilities(TestVolumeProxy):
+    def test_capabilites_get(self):
+        self.verify_get(self.proxy.get_capabilities, capabilities.Capabilities)
+
+
 class TestSnapshot(TestVolumeProxy):
     def test_snapshot_get(self):
         self.verify_get(self.proxy.get_snapshot, snapshot.Snapshot)
