@@ -15,10 +15,11 @@
 import io
 import operator
 import tempfile
+from unittest import mock
 import uuid
 
-from openstack.cloud import exc
 from openstack.cloud import meta
+from openstack import connection
 from openstack import exceptions
 from openstack.image.v1 import image as image_v1
 from openstack.image.v2 import image
@@ -66,29 +67,9 @@ class TestImage(BaseTestImage):
         super(TestImage, self).setUp()
         self.use_glance()
 
-    def test_config_v1(self):
-        self.cloud.config.config['image_api_version'] = '1'
-        # We override the scheme of the endpoint with the scheme of the service
-        # because glance has a bug where it doesn't return https properly.
-        self.assertEqual(
-            'https://image.example.com/v1/',
-            self.cloud._image_client.get_endpoint(),
-        )
-        self.assertEqual('1', self.cloud_config.get_api_version('image'))
-
-    def test_config_v2(self):
-        self.cloud.config.config['image_api_version'] = '2'
-        # We override the scheme of the endpoint with the scheme of the service
-        # because glance has a bug where it doesn't return https properly.
-        self.assertEqual(
-            'https://image.example.com/v2/',
-            self.cloud._image_client.get_endpoint(),
-        )
-        self.assertEqual('2', self.cloud_config.get_api_version('image'))
-
     def test_download_image_no_output(self):
         self.assertRaises(
-            exc.OpenStackCloudException,
+            exceptions.SDKException,
             self.cloud.download_image,
             self.image_name,
         )
@@ -96,7 +77,7 @@ class TestImage(BaseTestImage):
     def test_download_image_two_outputs(self):
         fake_fd = io.BytesIO()
         self.assertRaises(
-            exc.OpenStackCloudException,
+            exceptions.SDKException,
             self.cloud.download_image,
             self.image_name,
             output_path='fake_path',
@@ -128,7 +109,7 @@ class TestImage(BaseTestImage):
             ]
         )
         self.assertRaises(
-            exc.OpenStackCloudResourceNotFound,
+            exceptions.NotFoundException,
             self.cloud.download_image,
             self.image_name,
             output_path='fake_path',
@@ -184,6 +165,20 @@ class TestImage(BaseTestImage):
         self.assertEqual(output_file.read(), self.output)
         self.assert_calls()
 
+    @mock.patch.object(connection.Connection, 'search_images')
+    def test_get_images(self, mock_search):
+        image1 = dict(id='123', name='mickey')
+        mock_search.return_value = [image1]
+        r = self.cloud.get_image('mickey')
+        self.assertIsNotNone(r)
+        self.assertDictEqual(image1, r)
+
+    @mock.patch.object(connection.Connection, 'search_images')
+    def test_get_image_not_found(self, mock_search):
+        mock_search.return_value = []
+        r = self.cloud.get_image('doesNotExist')
+        self.assertIsNone(r)
+
     def test_get_image_name(self, cloud=None):
         cloud = cloud or self.cloud
         self.register_uris(
@@ -775,7 +770,7 @@ class TestImage(BaseTestImage):
 
     def test_create_image_task(self):
         self.cloud.image_api_use_tasks = True
-        endpoint = self.cloud._object_store_client.get_endpoint()
+        endpoint = self.cloud.object_store.get_endpoint()
 
         task_id = str(uuid.uuid4())
         args = dict(
@@ -1054,7 +1049,7 @@ class TestImage(BaseTestImage):
 
     def test_delete_image_task(self):
         self.cloud.image_api_use_tasks = True
-        endpoint = self.cloud._object_store_client.get_endpoint()
+        endpoint = self.cloud.object_store.get_endpoint()
 
         object_path = self.fake_image_dict['owner_specified.openstack.object']
 
@@ -1116,7 +1111,7 @@ class TestImage(BaseTestImage):
     def test_delete_autocreated_image_objects(self):
         self.use_keystone_v3()
         self.cloud.image_api_use_tasks = True
-        endpoint = self.cloud._object_store_client.get_endpoint()
+        endpoint = self.cloud.object_store.get_endpoint()
         other_image = self.getUniqueString('no-delete')
 
         self.register_uris(
@@ -1358,7 +1353,7 @@ class TestImage(BaseTestImage):
         )
 
         self.assertRaises(
-            exc.OpenStackCloudHTTPError,
+            exceptions.HttpException,
             self._call_create_image,
             self.image_name,
         )
@@ -1474,7 +1469,7 @@ class TestImage(BaseTestImage):
         )
 
         self.assertRaises(
-            exc.OpenStackCloudHTTPError,
+            exceptions.HttpException,
             self._call_create_image,
             self.image_name,
         )
@@ -1560,7 +1555,7 @@ class TestImage(BaseTestImage):
         self.cloud.image_api_use_tasks = False
 
         self.assertRaises(
-            exc.OpenStackCloudException,
+            exceptions.SDKException,
             self._call_create_image,
             self.image_name,
             allow_duplicates=True,
@@ -1924,58 +1919,6 @@ class TestImageSuburl(BaseTestImage):
         self.assert_calls()
 
 
-class TestImageV1Only(base.TestCase):
-    def setUp(self):
-        super(TestImageV1Only, self).setUp()
-        self.use_glance(image_version_json='image-version-v1.json')
-
-    def test_config_v1(self):
-        self.cloud.config.config['image_api_version'] = '1'
-        # We override the scheme of the endpoint with the scheme of the service
-        # because glance has a bug where it doesn't return https properly.
-        self.assertEqual(
-            'https://image.example.com/v1/',
-            self.cloud._image_client.get_endpoint(),
-        )
-        self.assertTrue(self.cloud._is_client_version('image', 1))
-
-    def test_config_v2(self):
-        self.cloud.config.config['image_api_version'] = '2'
-        # We override the scheme of the endpoint with the scheme of the service
-        # because glance has a bug where it doesn't return https properly.
-        self.assertEqual(
-            'https://image.example.com/v1/',
-            self.cloud._image_client.get_endpoint(),
-        )
-        self.assertFalse(self.cloud._is_client_version('image', 2))
-
-
-class TestImageV2Only(base.TestCase):
-    def setUp(self):
-        super(TestImageV2Only, self).setUp()
-        self.use_glance(image_version_json='image-version-v2.json')
-
-    def test_config_v1(self):
-        self.cloud.config.config['image_api_version'] = '1'
-        # We override the scheme of the endpoint with the scheme of the service
-        # because glance has a bug where it doesn't return https properly.
-        self.assertEqual(
-            'https://image.example.com/v2/',
-            self.cloud._image_client.get_endpoint(),
-        )
-        self.assertTrue(self.cloud._is_client_version('image', 2))
-
-    def test_config_v2(self):
-        self.cloud.config.config['image_api_version'] = '2'
-        # We override the scheme of the endpoint with the scheme of the service
-        # because glance has a bug where it doesn't return https properly.
-        self.assertEqual(
-            'https://image.example.com/v2/',
-            self.cloud._image_client.get_endpoint(),
-        )
-        self.assertTrue(self.cloud._is_client_version('image', 2))
-
-
 class TestImageVolume(BaseTestImage):
     def setUp(self):
         super(TestImageVolume, self).setUp()
@@ -2079,32 +2022,3 @@ class TestImageVolume(BaseTestImage):
         )
 
         self.assert_calls()
-
-
-class TestImageBrokenDiscovery(base.TestCase):
-    def setUp(self):
-        super(TestImageBrokenDiscovery, self).setUp()
-        self.use_glance(image_version_json='image-version-broken.json')
-
-    def test_url_fix(self):
-        # image-version-broken.json has both http urls and localhost as the
-        # host. This is testing that what is discovered is https, because
-        # that's what's in the catalog, and image.example.com for the same
-        # reason.
-        self.register_uris(
-            [
-                dict(
-                    method='GET',
-                    uri=self.get_mock_url(
-                        'image', append=['images'], base_url_append='v2'
-                    ),
-                    json={'images': []},
-                )
-            ]
-        )
-        self.assertEqual([], self.cloud.list_images())
-        self.assertEqual(
-            self.cloud._image_client.get_endpoint(),
-            'https://image.example.com/v2/',
-        )
-        self.assert_calls()
