@@ -28,14 +28,16 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
         super(TestMessageProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
 
+
+class TestMessageQueue(TestMessageProxy):
     def test_queue_create(self):
         self.verify_create(self.proxy.create_queue, queue.Queue)
 
     def test_queue_get(self):
         self.verify_get(self.proxy.get_queue, queue.Queue)
         self.verify_get_overrided(
-            self.proxy, queue.Queue,
-            'openstack.message.v2.queue.Queue')
+            self.proxy, queue.Queue, 'openstack.message.v2.queue.Queue'
+        )
 
     def test_queues(self):
         self.verify_list(self.proxy.queues, queue.Queue)
@@ -46,6 +48,8 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
     def test_queue_delete_ignore(self):
         self.verify_delete(self.proxy.delete_queue, queue.Queue, True)
 
+
+class TestMessageMessage(TestMessageProxy):
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_message_post(self, mock_get_resource):
         message_obj = message.Message(queue_name="test_queue")
@@ -54,9 +58,11 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             "openstack.message.v2.message.Message.post",
             self.proxy.post_message,
             method_args=["test_queue", ["msg1", "msg2"]],
-            expected_args=[self.proxy, ["msg1", "msg2"]])
-        mock_get_resource.assert_called_once_with(message.Message, None,
-                                                  queue_name="test_queue")
+            expected_args=[self.proxy, ["msg1", "msg2"]],
+        )
+        mock_get_resource.assert_called_once_with(
+            message.Message, None, queue_name="test_queue"
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_message_get(self, mock_get_resource):
@@ -65,18 +71,22 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             "openstack.proxy.Proxy._get",
             self.proxy.get_message,
             method_args=["test_queue", "resource_or_id"],
-            expected_args=[message.Message, "resource_or_id"])
-        mock_get_resource.assert_called_once_with(message.Message,
-                                                  "resource_or_id",
-                                                  queue_name="test_queue")
+            expected_args=[message.Message, "resource_or_id"],
+        )
+        mock_get_resource.assert_called_once_with(
+            message.Message, "resource_or_id", queue_name="test_queue"
+        )
         self.verify_get_overrided(
-            self.proxy, message.Message,
-            'openstack.message.v2.message.Message')
+            self.proxy, message.Message, 'openstack.message.v2.message.Message'
+        )
 
     def test_messages(self):
-        self.verify_list(self.proxy.messages, message.Message,
-                         method_kwargs={"queue_name": "test_queue"},
-                         expected_kwargs={"queue_name": "test_queue"})
+        self.verify_list(
+            self.proxy.messages,
+            message.Message,
+            method_kwargs={"queue_name": "test_queue"},
+            expected_kwargs={"queue_name": "test_queue"},
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_message_delete(self, mock_get_resource):
@@ -88,11 +98,12 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             self.proxy.delete_message,
             method_args=["test_queue", "resource_or_id", None, False],
             expected_args=[message.Message, fake_message],
-            expected_kwargs={"ignore_missing": False})
+            expected_kwargs={"ignore_missing": False},
+        )
         self.assertIsNone(fake_message.claim_id)
-        mock_get_resource.assert_called_once_with(message.Message,
-                                                  "resource_or_id",
-                                                  queue_name="test_queue")
+        mock_get_resource.assert_called_once_with(
+            message.Message, "resource_or_id", queue_name="test_queue"
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_message_delete_claimed(self, mock_get_resource):
@@ -104,11 +115,12 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             self.proxy.delete_message,
             method_args=["test_queue", "resource_or_id", "claim_id", False],
             expected_args=[message.Message, fake_message],
-            expected_kwargs={"ignore_missing": False})
+            expected_kwargs={"ignore_missing": False},
+        )
         self.assertEqual("claim_id", fake_message.claim_id)
-        mock_get_resource.assert_called_once_with(message.Message,
-                                                  "resource_or_id",
-                                                  queue_name="test_queue")
+        mock_get_resource.assert_called_once_with(
+            message.Message, "resource_or_id", queue_name="test_queue"
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_message_delete_ignore(self, mock_get_resource):
@@ -120,19 +132,23 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             self.proxy.delete_message,
             method_args=["test_queue", "resource_or_id", None, True],
             expected_args=[message.Message, fake_message],
-            expected_kwargs={"ignore_missing": True})
+            expected_kwargs={"ignore_missing": True},
+        )
         self.assertIsNone(fake_message.claim_id)
-        mock_get_resource.assert_called_once_with(message.Message,
-                                                  "resource_or_id",
-                                                  queue_name="test_queue")
+        mock_get_resource.assert_called_once_with(
+            message.Message, "resource_or_id", queue_name="test_queue"
+        )
 
+
+class TestMessageSubscription(TestMessageProxy):
     def test_subscription_create(self):
         self._verify(
             "openstack.message.v2.subscription.Subscription.create",
             self.proxy.create_subscription,
             method_args=["test_queue"],
             expected_args=[self.proxy],
-            expected_kwargs={"base_path": None})
+            expected_kwargs={"base_path": None},
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_subscription_get(self, mock_get_resource):
@@ -141,50 +157,69 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             "openstack.proxy.Proxy._get",
             self.proxy.get_subscription,
             method_args=["test_queue", "resource_or_id"],
-            expected_args=[subscription.Subscription, "resource_or_id"])
+            expected_args=[subscription.Subscription, "resource_or_id"],
+        )
         mock_get_resource.assert_called_once_with(
-            subscription.Subscription, "resource_or_id",
-            queue_name="test_queue")
+            subscription.Subscription,
+            "resource_or_id",
+            queue_name="test_queue",
+        )
         self.verify_get_overrided(
-            self.proxy, subscription.Subscription,
-            'openstack.message.v2.subscription.Subscription')
+            self.proxy,
+            subscription.Subscription,
+            'openstack.message.v2.subscription.Subscription',
+        )
 
     def test_subscriptions(self):
-        self.verify_list(self.proxy.subscriptions, subscription.Subscription,
-                         method_kwargs={"queue_name": "test_queue"},
-                         expected_kwargs={"queue_name": "test_queue"})
+        self.verify_list(
+            self.proxy.subscriptions,
+            subscription.Subscription,
+            method_kwargs={"queue_name": "test_queue"},
+            expected_kwargs={"queue_name": "test_queue"},
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_subscription_delete(self, mock_get_resource):
         mock_get_resource.return_value = "test_subscription"
-        self.verify_delete(self.proxy.delete_subscription,
-                           subscription.Subscription,
-                           ignore_missing=False,
-                           method_args=["test_queue", "resource_or_id"],
-                           expected_args=["test_subscription"])
+        self.verify_delete(
+            self.proxy.delete_subscription,
+            subscription.Subscription,
+            ignore_missing=False,
+            method_args=["test_queue", "resource_or_id"],
+            expected_args=["test_subscription"],
+        )
         mock_get_resource.assert_called_once_with(
-            subscription.Subscription, "resource_or_id",
-            queue_name="test_queue")
+            subscription.Subscription,
+            "resource_or_id",
+            queue_name="test_queue",
+        )
 
     @mock.patch.object(proxy_base.Proxy, '_get_resource')
     def test_subscription_delete_ignore(self, mock_get_resource):
         mock_get_resource.return_value = "test_subscription"
-        self.verify_delete(self.proxy.delete_subscription,
-                           subscription.Subscription,
-                           ignore_missing=True,
-                           method_args=["test_queue", "resource_or_id"],
-                           expected_args=["test_subscription"])
+        self.verify_delete(
+            self.proxy.delete_subscription,
+            subscription.Subscription,
+            ignore_missing=True,
+            method_args=["test_queue", "resource_or_id"],
+            expected_args=["test_subscription"],
+        )
         mock_get_resource.assert_called_once_with(
-            subscription.Subscription, "resource_or_id",
-            queue_name="test_queue")
+            subscription.Subscription,
+            "resource_or_id",
+            queue_name="test_queue",
+        )
 
+
+class TestMessageClaim(TestMessageProxy):
     def test_claim_create(self):
         self._verify(
             "openstack.message.v2.claim.Claim.create",
             self.proxy.create_claim,
             method_args=["test_queue"],
             expected_args=[self.proxy],
-            expected_kwargs={"base_path": None})
+            expected_kwargs={"base_path": None},
+        )
 
     def test_claim_get(self):
         self._verify(
@@ -192,10 +227,11 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             self.proxy.get_claim,
             method_args=["test_queue", "resource_or_id"],
             expected_args=[claim.Claim, "resource_or_id"],
-            expected_kwargs={"queue_name": "test_queue"})
+            expected_kwargs={"queue_name": "test_queue"},
+        )
         self.verify_get_overrided(
-            self.proxy, claim.Claim,
-            'openstack.message.v2.claim.Claim')
+            self.proxy, claim.Claim, 'openstack.message.v2.claim.Claim'
+        )
 
     def test_claim_update(self):
         self._verify(
@@ -204,17 +240,21 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             method_args=["test_queue", "resource_or_id"],
             method_kwargs={"k1": "v1"},
             expected_args=[claim.Claim, "resource_or_id"],
-            expected_kwargs={"queue_name": "test_queue", "k1": "v1"})
+            expected_kwargs={"queue_name": "test_queue", "k1": "v1"},
+        )
 
     def test_claim_delete(self):
-        self.verify_delete(self.proxy.delete_claim,
-                           claim.Claim,
-                           ignore_missing=False,
-                           method_args=["test_queue", "test_claim"],
-                           expected_args=["test_claim"],
-                           expected_kwargs={
-                               "queue_name": "test_queue",
-                               "ignore_missing": False})
+        self.verify_delete(
+            self.proxy.delete_claim,
+            claim.Claim,
+            ignore_missing=False,
+            method_args=["test_queue", "test_claim"],
+            expected_args=["test_claim"],
+            expected_kwargs={
+                "queue_name": "test_queue",
+                "ignore_missing": False,
+            },
+        )
 
     def test_claim_delete_ignore(self):
         self.verify_delete(
@@ -224,5 +264,7 @@ class TestMessageProxy(test_proxy_base.TestProxyBase):
             method_args=["test_queue", "test_claim"],
             expected_args=["test_claim"],
             expected_kwargs={
-                "queue_name": "test_queue", "ignore_missing": True,
-            })
+                "queue_name": "test_queue",
+                "ignore_missing": True,
+            },
+        )
